@@ -16,7 +16,7 @@ typedef struct
 } WAVHeader;
 void printWavHeader(WAVHeader *hdr);
 
-typedef enum CHANNEL_CONF
+typedef enum 
 {
     CHANNEL_INVALID=0,
     CHANNEL_MONO,
@@ -30,5 +30,20 @@ typedef enum CHANNEL_CONF
     CHANNEL_DOLBY_PROLOGIC,
     CHANNEL_DOLBY_PROLOGIC2,
     CHANNEL_LAST
+} CHANNEL_CONF;
+
+typedef struct
+{
+  const char    *desc;
+  CHANNEL_CONF  conf;
+}AudioChannelDesc;
+const AudioChannelDesc localDownmixing[]=
+{
+  {"No downmixing (multichannel)", CHANNEL_INVALID},
+  {"Stereo", CHANNEL_STEREO},
+  {"Dolby Prologic", CHANNEL_DOLBY_PROLOGIC},
+  {"Dolby Prologic II", CHANNEL_DOLBY_PROLOGIC2}
+  
 };
+#define NB_LOCAL_DOWNMIX (sizeof(localDownmixing)/sizeof(AudioChannelDesc))
 #endif
