@@ -24,14 +24,13 @@ Split a stream into packet(s)
 #include <string.h>
 #include <ADM_assert.h>
 #include <math.h>
-#ifdef CYG_MANGLING
+#ifdef ADM_WIN32
 #include <io.h>
 #endif
 
-#include "ADM_library/default.h"
+#include "default.h"
 #include "ADM_editor/ADM_Video.h"
-#include "ADM_library/fourcc.h"
-#include "ADM_openDML/ADM_openDML.h"
+#include "fourcc.h"
 #include "aviaudio.hxx"
 
 #include "ADM_audio/ADM_a52info.h"
@@ -100,6 +99,8 @@ _refill:
 		case WAV_PCM:
                 case WAV_8BITS_UNSIGNED:
 		case WAV_ULAW:
+                case WAV_MSADPCM:
+                case WAV_AMV_ADPCM:
 				return getPacketPCM(dest,len,samples);
 				break;
 		case WAV_AC3:
@@ -110,7 +111,7 @@ _refill:
 				return getPacketWMA(dest,len,samples);
 				break;
 		default:
-				printf("Unsupported!\n");
+				printf("*** PACKETIZER : Unsupported!\n");
 				return 0;
 	}
 	return 0;
@@ -189,7 +190,7 @@ uint8_t		AVDMGenericAudioStream::getPacketPCM(uint8_t *dest, uint32_t *len,
 				return 0;
 			}
                         if(_wavheader->encoding!=WAV_ULAW && _wavheader->encoding!=WAV_8BITS_UNSIGNED&&
-                                        _wavheader->encoding!=WAV_IMAADPCM)
+                                        _wavheader->encoding!=WAV_IMAADPCM  )
 			{
 				*samples=sample/2;
 			}
@@ -422,7 +423,15 @@ _retry:
 					mpegInfo.size);
 			*len=mpegInfo.size;
 			*samples=mpegInfo.samples;
-			packetHead+=startOffset+mpegInfo.size;
+			//packetHead+=startOffset+mpegInfo.size;
+                        // Patch from yhjvgskxwizgr (forum)
+                       if(startOffset < mpegInfo.size/2)  // we probably have our correct frame, so set head to the next
+                               packetHead+=startOffset+mpegInfo.size;
+                       else if(startOffset < mpegInfo.size)  // we probably have the next frame, so duplicate it to keep a/v synced
+                               packetHead+=startOffset;
+                       else  // we have next or later frame, so next time continue searching one frame later to keep a/v synced
+                               packetHead+=mpegInfo.size;
+                        // /Patch
 			return 1;
 }		
 //---
@@ -445,12 +454,12 @@ uint8_t		AVDMGenericAudioStream::getPacketAAC(uint8_t *dest, uint32_t *len,
 			{
 				// Error decoding mpeg
 				printf("AACInfo:** CANNOT FIND AAC/ADTS START CODE**\n");
-				packetHead+=8;
+				packetHead+=1;
 				return 0;
 			}
 			if(packetHead+startOffset+mpegInfo.size>packetTail)
 			{
-				printf("AAC packetizer: not enough data\n");
+				printf("AAC packetizer: not enough data (need %u, got %u)\n",mpegInfo.size,packetTail-packetHead-startOffset);
 				return 0;
 			}
 			memcpy(dest,&packetBuffer[packetHead+startOffset],
