@@ -16,7 +16,7 @@
  ***************************************************************************/
 #ifndef ADMAUDIOCODEC
 #define ADMAUDIOCODEC
-#define SCRATCH_PAD_SIZE (80000*2)
+#define SCRATCH_PAD_SIZE (100*1000*2)
 extern uint8_t scratchPad[];
 #define  ADMAC_BUFFER (48000*4)
 class ADM_Audiocodec
@@ -179,7 +179,7 @@ class ADM_faad : public     ADM_Audiocodec
 		uint32_t _inbuffer;	
 
 	public:
-		ADM_faad(uint32_t fourcc, WAVHeader *info, uint32_t l, uint8_t *d);
+		ADM_faad(uint32_t fourcc, uint32_t highEfficiency,WAVHeader *info, uint32_t l, uint8_t *d);
 		virtual	~ADM_faad();
 		virtual	void purge(void);
 		virtual	uint8_t run(uint8_t *inptr, uint32_t nbIn, float *outptr, uint32_t *nbOut);
@@ -258,5 +258,23 @@ class ADM_AudiocodecImaAdpcm : public     ADM_Audiocodec
 		virtual	uint8_t isCompressed(void) {return 1;}
 		virtual	uint8_t isDecompressable(void) {return 1;}
 };
+class ADM_AudiocodecMsAdpcm : public     ADM_Audiocodec
+{
+	protected:
+		uint32_t _inStock,_me,_channels;
+		int ss_div,ss_mul; // ???
+		void *_contextVoid;
+		uint8_t _buffer[ IMA_BUFFER];
+		uint32_t _head,_tail;
+
+	public:
+		ADM_AudiocodecMsAdpcm(uint32_t fourcc, WAVHeader *info);
+		virtual	~ADM_AudiocodecMsAdpcm();
+		virtual	uint8_t beginDecompress(void) {_head=_tail=0;return 1;}
+		virtual	uint8_t endDecompress(void) {_head=_tail=0;return 1;}
+		virtual	uint8_t run(uint8_t *inptr, uint32_t nbIn, float *outptr, uint32_t *nbOut);
+		virtual	uint8_t isCompressed(void) {return 1;}
+		virtual	uint8_t isDecompressable(void) {return 1;}
+};
 
 #endif
