@@ -30,7 +30,7 @@
 #include "faad.h"
 
 
-ADM_faad::ADM_faad( uint32_t fourcc ,WAVHeader *info,uint32_t l,uint8_t *d) :   ADM_Audiocodec(fourcc)
+ADM_faad::ADM_faad( uint32_t fourcc ,uint32_t highEfficiency,WAVHeader *info,uint32_t l,uint8_t *d) :   ADM_Audiocodec(fourcc)
 {
 faacDecConfigurationPtr conf;
 #ifdef OLD_FAAD_PROTO
@@ -47,22 +47,29 @@ unsigned char chan;
 		// Update the field we know about
 		conf->outputFormat=FAAD_FMT_16BIT;
 		conf->defSampleRate=info->frequency;
-		conf->defObjectType =LC;
+                if(!highEfficiency)
+                {
+		  conf->defObjectType =LC;
+                }else
+                {
+                   conf->defObjectType =HE_AAC;
+                }
 		faacDecSetConfiguration(_instance, conf);
+                printf("[FAAD] using %u bytes of extradata\n",l);
 		// if we have some extra data, it means we can init it from it
 		if(l)
 		{
 			_inited = 1;
 			faacDecInit2(_instance, d,l, &srate,&chan);
-			printf("Found :%d rate %d channels\n",srate,chan);
+			printf("[FAAD]Found :%d rate %d channels\n",srate,chan);
                         if(srate!=info->frequency)
                         {
-                            printf("Frequency mismatch!!! %d to %d (SBR ?)\n",info->frequency,srate);
+                            printf("[FAAD]Frequency mismatch!!! %d to %d (SBR ?)\n",info->frequency,srate);
                             info->frequency=srate;
                         }	
                         if(chan!=info->channels) // Ask for stereo !
                         {
-                             printf("channel mismatch!!! %d to %d \n",info->channels,chan);
+                             printf("[FAAD]channel mismatch!!! %d to %d \n",info->channels,chan);
                             info->channels=chan;
                         }
 		}
@@ -80,7 +87,7 @@ unsigned char chan;
 	ch_route.input_type[4] = CH_REAR_RIGHT;
 	ch_route.input_type[5] = CH_LFE;
 
-		printf("Faad decoder created\n");
+		printf("[FAAD]Faad decoder created\n");
 }
 
 ADM_faad::~ADM_faad()
@@ -165,13 +172,10 @@ uint8_t first=0;
 			{
 				printf("Faad: Error %d :%s\n",info.error,
 					faacDecGetErrorMessage(info.error));
-					/*
-				xin=info.bytesconsumed ;
-				if(!xin) xin=1;
-				memmove(_buffer,_buffer+xin,_inbuffer-xin);
-				_inbuffer-=xin;
-				return 1;*/
-				return 0;
+				printf("Bye consumed %u, bytes dropped %u \n",info.bytesconsumed,_inbuffer);
+
+                                _inbuffer=0; // Purge buffer
+				return 1;
 			}
 			if(first)
 			{
