@@ -51,7 +51,7 @@ uint8_t scratchPad[SCRATCH_PAD_SIZE];
        :  ADM_Audiocodec(fourcc)
  {
     _tail=_head=0;
-    ADM_assert(fourcc==WAV_WMA || fourcc==WAV_QDM2);	
+
     _contextVoid=(void *)avcodec_alloc_context();
     ADM_assert(_contextVoid);
     // Fills in some values...
@@ -59,23 +59,36 @@ uint8_t scratchPad[SCRATCH_PAD_SIZE];
     _context->channels = info->channels;
     _blockalign=_context->block_align = info->blockalign;
     _context->bit_rate = info->byterate*8;
-    if(fourcc==WAV_WMA)
+    switch(fourcc)
+    {
+      case WAV_WMA:
         _context->codec_id = CODEC_ID_WMAV2;
-    else
-        if(fourcc==WAV_QDM2)
+        break;
+      case WAV_QDM2:
         _context->codec_id = CODEC_ID_QDM2;
-            else ADM_assert(0);
+        break;
+      case WAV_AMV_ADPCM:
+        _context->codec_id = CODEC_ID_ADPCM_IMA_AMV;
+        _blockalign=1;
+        break;
+      case WAV_NELLYMOSER:
+        _context->codec_id = CODEC_ID_NELLYMOSER;
+        _blockalign=1;
+        break;
 
-    _context->extradata=(void *)d;
+      default:
+             ADM_assert(0);
+    }
+    _context->extradata=(uint8_t *)d;
     _context->extradata_size=(int)l;
     printf(" Using %ld bytes of extra header data\n",l);
     mixDump((uint8_t *)_context->extradata,_context->extradata_size);
 
    AVCodec *codec=avcodec_find_decoder(_context->codec_id);
-   if(!codec) {GUI_Error_HIG(_("Internal error"), _("Cannot open WMA2 codec."));ADM_assert(0);} 
+   if(!codec) {GUI_Error_HIG(QT_TR_NOOP("Internal error"), QT_TR_NOOP("Cannot open WMA2 codec."));ADM_assert(0);} 
     if (avcodec_open(_context, codec) < 0)
     {
-        printf("\n WMA decoder init failed !\n");
+        printf("\n Lavc audio decoder init failed !\n");
         ADM_assert(0);
     }
     if(!_blockalign)
@@ -121,7 +134,7 @@ int nbChunk;
         {
           nbChunk=(_tail-_head)/_blockalign;
           pout=SCRATCH_PAD_SIZE;
-          out=avcodec_decode_audio(_context,(int16_t *)scratchPad,
+          out=avcodec_decode_audio2(_context,(int16_t *)scratchPad,
                                    &pout,_buffer+_head,nbChunk*_blockalign);
                 
           if(out<0)
@@ -135,6 +148,10 @@ int nbChunk;
             printf("Produced : %u, buffer %u,in%u\n",pout,SCRATCH_PAD_SIZE,_tail-_head);
             ADM_assert(0); 
           }
+          if(_context->codec_id == CODEC_ID_NELLYMOSER)
+          { // Hack, it returns inconsistent size
+            out=nbChunk*_blockalign;
+          }
           _head+=out; // consumed bytes
           pout>>=1;
           *nbOut+=pout;
@@ -150,6 +167,7 @@ int nbChunk;
         return 1;
 }
 ///************************************************
+#ifdef USE_AMR_NB
   uint8_t ADM_AudiocodecAMR::beginDecompress( void ) 
    {
             _tail=_head=0;
@@ -179,7 +197,7 @@ int nbChunk;
         printf(" Opening AMR codec\n");
 
         AVCodec *codec=avcodec_find_decoder(CODEC_ID_AMR_NB);
-        if(!codec) {GUI_Error_HIG(_("Internal error"), _("Cannot open AMR codec."));ADM_assert(0);} 
+        if(!codec) {GUI_Error_HIG(QT_TR_NOOP("Internal error"), QT_TR_NOOP("Cannot open AMR codec."));ADM_assert(0);} 
         if (avcodec_open(_context, codec) < 0)
         {
             printf("\n AMR decoder init failed !\n");
@@ -217,7 +235,7 @@ int16_t *run16;
         _tail+=nbIn;
         while(_tail-_head>AMR_PACKET)
         {
-          out=avcodec_decode_audio(_context,(int16_t *)scratchPad,
+          out=avcodec_decode_audio2(_context,(int16_t *)scratchPad,
                                    &pout,_buffer+_head,_tail-_head);
                 
                 if(out<0)
@@ -240,5 +258,5 @@ int16_t *run16;
 
         return 1;
 }
-
+#endif
 //---
