@@ -44,7 +44,7 @@
 #include "ADM_audiodevice/ADM_deviceSDL.h"
 #endif
 
-#ifdef CYG_MANGLING
+#ifdef ADM_WIN32
 #include "ADM_audiodevice/ADM_deviceWin32.h"
 #endif
 
@@ -52,7 +52,11 @@
 #include "ADM_deviceEsd.h"
 #endif
 
-#ifdef CONFIG_DARWIN
+#ifdef USE_JACK
+#include "ADM_deviceJack.h"
+#endif
+
+#ifdef __APPLE__
 #include "ADM_audiodevice/ADM_deviceAudioCore.h"
 #endif
 
@@ -75,7 +79,6 @@ audioDevice *device=NULL;
 static AUDIO_DEVICE  currentDevice=DEVICE_DUMMY;
 static AUDIO_DEVICE ADM_audioByName(const char *name);
 static const char *ADM_audioById(AUDIO_DEVICE id);
-extern void DIA_getAudioDevice(AUDIO_DEVICE *id);
 
 void AVDM_audioSave( void )
 {
@@ -140,6 +143,7 @@ AUDIO_DEVICE id;
 			case DEVICE_SDL:
 			case DEVICE_WIN32:
 			case DEVICE_ESD:
+			case DEVICE_JACK:
 			
 						printf("Using real audio device\n");
 						AVDM_switch(id);
@@ -161,7 +165,7 @@ AUDIO_DEVICE id;
 			AVDM_switch(DEVICE_OSS);			
 			printf("\n Using OSS\n");
 		#else
-			#ifdef CYG_MANGLING
+			#ifdef ADM_WIN32
 			AVDM_switch(DEVICE_WIN32);
 			#else
                 #ifdef USE_ESD
@@ -174,19 +178,29 @@ AUDIO_DEVICE id;
 		#endif
 		}
 }
+
+void AVDM_cleanup(void)
+{
+	if(device)
+	{
+		delete device;
+		device=NULL;
+	}
+}
 // Switch the audio device class we are using
 //
 void AVDM_switch(AUDIO_DEVICE action)
 {
 	if(device)
-	       {
-				delete device;
-			}
-	device=NULL;
+	{
+		delete device;
+		device=NULL;
+	}
+
 	 currentDevice=DEVICE_DUMMY;
 	switch(action)
 	{
-#ifdef CONFIG_DARWIN
+#ifdef __APPLE__
 		  case  DEVICE_COREAUDIO :
 								device=new 	 coreAudioDevice;
 								currentDevice=DEVICE_COREAUDIO;;
@@ -194,18 +208,24 @@ void AVDM_switch(AUDIO_DEVICE action)
 								break;
 
 #endif
-#if defined(OSS_SUPPORT) && !defined(CYG_MANGLING)
+#if defined(OSS_SUPPORT) && !defined(ADM_WIN32)
 		  case  DEVICE_OSS :
 								device=new 	 ossAudioDevice;
 								currentDevice=DEVICE_OSS;;
 								break;
 #endif
-#if defined(USE_ESD) && !defined(CYG_MANGLING)
+#if defined(USE_ESD) && !defined(ADM_WIN32)
 		  case  DEVICE_ESD :
 								device=new 	 esdAudioDevice;
 								currentDevice=DEVICE_ESD;;
 								break;
 #endif
+#if defined(USE_JACK) && !defined(ADM_WIN32)
+		  case  DEVICE_JACK:
+								device=new 	 jackAudioDevice;
+								currentDevice=DEVICE_JACK;
+								break;
+#endif
 #ifdef USE_ARTS
 		case DEVICE_ARTS:
 								device=new 	 artsAudioDevice;
@@ -227,7 +247,7 @@ void AVDM_switch(AUDIO_DEVICE action)
 								break;
 #endif
 
-#ifdef CYG_MANGLING
+#ifdef ADM_WIN32
 		case DEVICE_WIN32:
 								device=new win32AudioDevice;
 								currentDevice=DEVICE_WIN32;
