@@ -17,7 +17,7 @@
  ***************************************************************************/
 #include "config.h"
 
-#if defined( USE_ESD ) && !defined(CYG_MANGLING)
+#if defined( USE_ESD ) && !defined(ADM_WIN32)
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -29,7 +29,7 @@
 #include <esd.h>
  
 
-#include "ADM_library/default.h"
+#include "default.h"
 #include "ADM_audiodevice.h"
 #include <ADM_assert.h>
 #include "ADM_audiodevice/ADM_deviceoss.h"
