@@ -21,7 +21,7 @@
 #include <ADM_assert.h>
 #include <math.h>
 
-#include "ADM_library/default.h"
+#include "ADM_utilities/default.h"
 
 #include "ADM_audiofilter/audiofilter_limiter_param.h"
 #include "ADM_audiofilter/audiofilter_normalize_param.h"
@@ -43,13 +43,12 @@
 
 #include "prefs.h"
 
-#include "ADM_toolkit/ADM_debugID.h"
+#include "ADM_osSupport/ADM_debugID.h"
 #define MODULE_NAME MODULE_AUDIO_FILTER
-#include "ADM_toolkit/ADM_debug.h"
+#include "ADM_osSupport/ADM_debug.h"
 
 extern void UI_setAProcessToggleStatus( uint8_t status );
 extern uint8_t DIA_audioCodec( AUDIOENCODER *codec );
-extern int DIA_audioEncoder(int *pmode, int *pbitrate,const char *title);
 extern void UI_setAudioCodec( int i);
 uint32_t audioFilterGetNbEncoder(void);
 const char* audioFilterGetIndexedName(uint32_t i);
@@ -96,7 +95,7 @@ static Mixer_String Mixer_strings[]=
 
 extern void UI_PrintCurrentACodec( const char *s);
 
-AUDIOENCODER  activeAudioEncoder=  AUDIOENC_NONE;
+AUDIOENCODER  activeAudioEncoder=  AUDIOENC_COPY;
 /*----------------------------------*/
 GAINparam audioGain;
 int  audioFreq=48000;
@@ -175,6 +174,10 @@ uint32_t audioGetResample(void)
       return audioFreq;
         
 }
+uint32_t audioGetDrc(void)
+{
+  return audioDRC; 
+}
 uint32_t audioGetDelay(void)
 {
         if(audioShift && audioDelay)
@@ -243,6 +246,11 @@ uint8_t audioFilterFilm2Pal(uint8_t onoff)
 	else audioFilmConv=FILMCONV_NONE;
 	return 1;
 }
+uint8_t audioFilterDrc(uint8_t onoff)
+{
+  audioDRC=onoff;
+  return 1; 
+}
 uint8_t audioFilterPal2Film(uint8_t onoff)
 {
         if(onoff) audioFilmConv=FILMCONV_PAL2FILM;
@@ -262,7 +270,8 @@ void audioFilterResample(uint32_t onoff)
 
 } 
 //______________________________
-#include "ADM_gui2/GUI_ui.h"
+//#include "ADM_gui2/GUI_ui.h"
+uint8_t UI_setTimeShift(int onoff,int value);
 extern  int DIA_getAudioFilter(GAINparam *normalized, RESAMPLING *downsamplingmethod, int *tshifted,
   			 int *shiftvalue, int *drc,int *freqvalue,FILMCONV *filmconv,CHANNEL_CONF *channel);
 
@@ -396,7 +405,6 @@ void audioPrintCurrentCodec(void)
 	audioPrintCurrentCodec();
 
 }
-
 void audioCodecSelect( void )
 {
 	DIA_audioCodec( &activeAudioEncoder );
@@ -423,4 +431,34 @@ void audioSetResample(uint32_t fq)
 	audioResampleMode=RESAMPLING_CUSTOM;
 	audioFreq=fq;
 }
+/**
+ * 	\fn getAudioOuputTag
+ *  \brief Return the encoding of the currently selected codec
+ *  Must be called only in process mode, else it is meaningless.
+ */
+uint32_t audioFilter_getOuputCodec(void)
+{
+	
+	for(uint32_t i=0;i<sizeof(myCodecList)/sizeof(CODECLIST);i++)
+		{
+			if(activeAudioEncoder==myCodecList[i].codec)
+			{
+				return myCodecList[i].wavTag;
+			}
+		
+		}
+	ADM_assert(0);
+	return WAV_PCM;
+}
+/**
+ * 	\fn getAudioOuputFrequency
+ *  \brief Return the encoding of the currently selected codec
+ */
+uint32_t audioFilter_getOuputFrequency(uint32_t inputFrequency)
+{
+	if(activeAudioEncoder==AUDIOENC_COPY) return inputFrequency;
+	if(audioResampleMode == RESAMPLING_NONE) return inputFrequency;
+	return audioFreq;
+}
+//EOF
 
