@@ -1,8 +1,8 @@
 
 #ifndef FAAC_PARAM_H
 #define FAAC_PARAM_H
-typedef struct FAAC_encoderParam
+typedef struct 
 {
   uint32_t dummy;
-};
+}FAAC_encoderParam;
 #endif
