@@ -1,14 +1,14 @@
 #ifndef AUDM_LAME_PARAM_H
 #define AUDM_LAME_PARAM_H
 
-typedef enum ADM_LAME_PRESET
+typedef enum 
 {
   ADM_LAME_PRESET_CBR,
   ADM_LAME_PRESET_ABR,
   ADM_LAME_PRESET_EXTREME
-};
+}ADM_LAME_PRESET;
 
-typedef struct ADM_PRESET_DEFINITION
+typedef struct 
 {
   ADM_LAME_PRESET preset;
   const char	*name;
@@ -20,11 +20,12 @@ static const ADM_PRESET_DEFINITION      presetDefinition[]=
   {ADM_LAME_PRESET_EXTREME,"Extreme"}
 };    
 
-typedef struct LAME_encoderParam
+typedef struct 
 {
   ADM_LAME_PRESET preset;
   ADM_mode        mode;
   uint32_t        quality;
-};
+  uint32_t        disableReservoir; // usefull for strict CBR (FLV)
+}LAME_encoderParam;
 
 #endif
