@@ -82,7 +82,7 @@
 
 #include <ADM_assert.h>
 
-#include "ADM_library/default.h"
+#include "ADM_utilities/default.h"
 
 #include "audioprocess.hxx"
 #include "resampl.h"
