@@ -25,7 +25,6 @@
 #include <math.h>
 
 
-#include "ADM_vp32/ADM_vp3.h"
 
 #ifdef USE_FFMPEG
 extern "C"
@@ -33,7 +32,7 @@ extern "C"
 #include "ADM_lavcodec.h"
 };
 #endif
-#include "ADM_library/default.h"
+#include "ADM_utilities/default.h"
 #ifdef BIG_ENDIAN
 #undef BIG_ENDIAN
 #endif
@@ -52,7 +51,7 @@ extern "C"
 #include "ADM_codecs/ADM_uyvy.h"
 #include "ADM_codecs/ADM_xvideco.h"
 
-#include "ADM_library/fourcc.h"
+#include "ADM_utilities/fourcc.h"
 
 #ifdef USE_FFMPEG
 #include "ADM_codecs/ADM_ffmp43.h"
@@ -66,7 +65,6 @@ extern "C"
 #include "ADM_codecs/ADM_theora_dec.h"
 #endif
 #include "ADM_codecs/ADM_mpeg.h"
-#include "ADM_codecs/ADM_vp3.h"
 #include "ADM_codecs/ADM_png.h"
 #include "ADM_toolkit/toolkit.hxx"
 #include <ADM_assert.h>
@@ -92,6 +90,7 @@ isMpeg4Compatible (uint32_t fourcc)
   CHECK ("XVID");
   CHECK ("BLZ0");
   CHECK ("M4S2");
+  CHECK ("3IV2");
 
   return divx4;
 
@@ -114,7 +113,7 @@ isMpeg12Compatible (uint32_t fourcc)
   CHECK ("mpg1");
   CHECK ("mpg2");
   SWAP32 (fourcc);
-  if (fourcc == 0x10000002)
+  if (fourcc == 0x10000002 || fourcc==0x10000001) //Mplayer fourcc
     mpeg = 1;
   return mpeg;
 #undef CHECK
@@ -158,15 +157,29 @@ isMSMpeg4Compatible (uint32_t fourcc)
 
 #undef CHECK
 }
+uint8_t
+isDVCompatible (uint32_t fourcc)
+{
+#define CHECK(x) if(fourCC::check(fourcc,(uint8_t *)x)) \
+						{dv=1; }
+
+  uint8_t dv = 0;
+
+  CHECK ("dvsd");
+  CHECK ("DVDS");
+  CHECK ("dvpp");
+
+  return dv;
+
+#undef CHECK
+}
+
 
 uint8_t
-  decoders::uncompress (uint8_t * in, ADMImage * out, uint32_t len,
-			uint32_t * flag)
+  decoders::uncompress (ADMCompressedImage * in, ADMImage * out)
 {
   UNUSED_ARG (in);
   UNUSED_ARG (out);
-  UNUSED_ARG (len);
-  UNUSED_ARG (flag);
   return 0;
 }
 decoders *
@@ -190,9 +203,9 @@ decoders *getDecoderH264noLogic (uint32_t fcc, uint32_t w, uint32_t h, uint32_t
 }
 decoders *
 getDecoder (uint32_t fcc, uint32_t w, uint32_t h, uint32_t extraLen,
-	    uint8_t * extraData)
+	    uint8_t * extraData,uint32_t bpp)
 {
-
+  printf("\nSearching decoder (%d x %d, extradataSize:%d)...\n",w,h,extraLen);
   if (isMSMpeg4Compatible (fcc) == 1)
     {
       // For div3, no problem we take ffmpeg
@@ -201,9 +214,7 @@ getDecoder (uint32_t fcc, uint32_t w, uint32_t h, uint32_t extraLen,
     }
 
 #ifdef USE_FFMPEG
-  if (fourCC::check (fcc, (uint8_t *) "dvsd")
-      || fourCC::check (fcc, (uint8_t *) "DVDS")
-      || fourCC::check (fcc, (uint8_t *) "CDVC"))
+  if (isDVCompatible(fcc))//"CDVC"))
     {
 
       return (decoders *) (new decoderFFDV (w, h, extraLen, extraData));
@@ -216,6 +227,12 @@ getDecoder (uint32_t fcc, uint32_t w, uint32_t h, uint32_t extraLen,
       return (decoders *) (new decoderFFMP42 (w, h));
     }
 #endif
+    if (fourCC::check (fcc, (uint8_t *) "FLV1"))
+    {
+      return (decoders *) (new decoderFFFLV1 (w, h,extraLen, extraData));
+    }
+  
+    
 #ifdef USE_FFMPEG
   if (fourCC::check (fcc, (uint8_t *) "H263"))
     {
@@ -225,7 +242,7 @@ getDecoder (uint32_t fcc, uint32_t w, uint32_t h, uint32_t extraLen,
   if (fourCC::check (fcc, (uint8_t *) "HFYU"))
     {
 
-      return (decoders *) (new decoderFFhuff (w, h, extraLen, extraData));
+      return (decoders *) (new decoderFFhuff (w, h, extraLen, extraData,bpp));
     }
 #ifdef USE_PNG
   if (fourCC::check (fcc, (uint8_t *) "PNG "))
@@ -234,11 +251,15 @@ getDecoder (uint32_t fcc, uint32_t w, uint32_t h, uint32_t extraLen,
       return (decoders *) (new decoderPng (w, h));
     }
 #endif
+ if (fourCC::check (fcc, (uint8_t *) "cvid"))
+    {
 
+      return (decoders *) (new decoderFFCinepak (w, h, extraLen, extraData));
+    }
   if (fourCC::check (fcc, (uint8_t *) "FFVH"))
     {
 
-      return (decoders *) (new decoderFF_ffhuff (w, h, extraLen, extraData));
+      return (decoders *) (new decoderFF_ffhuff (w, h, extraLen, extraData,bpp));
     }
   if (fourCC::check (fcc, (uint8_t *) "SVQ3"))
     {
@@ -248,10 +269,14 @@ getDecoder (uint32_t fcc, uint32_t w, uint32_t h, uint32_t extraLen,
   if (fourCC::check (fcc, (uint8_t *) "tscc"))
     {
 
-      return (decoders *) (new decoderCamtasia (w, h, 16));
-//stream->biBitCount)); // Fixme should be bit per pixel
+      return (decoders *) (new decoderCamtasia (w, h, bpp));
     }
 
+     if (fourCC::check (fcc, (uint8_t *) "CRAM"))
+    {
+
+      return (decoders *) (new decoderFFCRAM (w, h, extraLen, extraData));
+    }
   if (fourCC::check (fcc, (uint8_t *) "WMV2"))
     {
 
@@ -268,6 +293,13 @@ getDecoder (uint32_t fcc, uint32_t w, uint32_t h, uint32_t extraLen,
 
       return (decoders *) (new decoderFFWMV3 (w, h, extraLen, extraData));
     }
+
+    if (fourCC::check (fcc, (uint8_t *) "WVC1"))
+    {
+
+      return (decoders *) (new decoderFFVC1 (w, h, extraLen, extraData));
+    }
+
 if (fourCC::check (fcc, (uint8_t *) "FFV1"))
     {
 
@@ -293,12 +325,17 @@ if (fourCC::check (fcc, (uint8_t *) "FFV1"))
 
   if (isMpeg4Compatible (fcc) == 1)
     {
-      return (decoders *) (new decoderFFMpeg4 (w, h, extraLen, extraData));
+      return (decoders *) (new decoderFFMpeg4 (w, h, fcc,extraLen, extraData));
       //    return(decoders *)( new decoderXvid(w,h));
       //    return(decoders *)( new decoderDIVX(w,h));
     }
 
-  if (fourCC::check (fcc, (uint8_t *) "MJPG")
+  if (fourCC::check (fcc, (uint8_t *) "MJPB"))
+    {
+      printf ("\n using FF mjpeg codec\n");
+      return (decoders *) (new decoderFFMjpegB (w, h,extraLen,extraData));
+    }
+if (fourCC::check (fcc, (uint8_t *) "MJPG")
       || fourCC::check (fcc, (uint8_t *) "mjpa"))
     {
 #if  0
@@ -327,37 +364,34 @@ if (fourCC::check (fcc, (uint8_t *) "FFV1"))
       printf ("\n using YUY2 codec\n");
       return (decoders *) (new decoderYUY2 (w, h));
     }
+  if (fourCC::check (fcc, (uint8_t *) "AMV "))
+    {
+      printf ("\n using AMV codec\n");
+      return (decoders *) (new decoderFFAMV (w, h,extraLen,extraData));
+    }
 
+    
+  if (fourCC::check (fcc, (uint8_t *) "VP6F"))
+    {
+      printf ("\n using VP6F codec\n");
+      return (decoders *) (new decoderFFVP6F (w, h,extraLen,extraData));
+    }
 
 
   if ((fcc == 0) || fourCC::check (fcc, (uint8_t *) "RGB "))
     {
       // RGB 16 Codecs
       printf ("\n using RGB codec\n");
-      return (decoders *) (new decoderRGB16 (w, h));
+      return (decoders *) (new decoderRGB16 (w, h, 0, bpp));
 
     }
  if ((fcc == 0) || fourCC::check (fcc, (uint8_t *) "DIB "))
     {
       // RGB 16 Codecs
       printf ("\n using RGB-DIB codec\n");
-      return (decoders *) (new decoderRGB16 (w, h,1));
+      return (decoders *) (new decoderRGB16 (w, h, 1, bpp));
 
     }
-#ifdef USE_THEORA
-
-  if (fourCC::check (fcc, (uint8_t *) "VP31"))
-    {
-      printf ("\n using Theora codec\n");
-      return (decoders *) (new decoderTheora (w, h));
-    }
-#else
-  if (fourCC::check (fcc, (uint8_t *) "VP31"))
-    {
-      printf ("\n using VP3 codec\n");
-      return (decoders *) (new decoderVP3 (w, h));
-    }
-#endif
   if (isMpeg12Compatible (fcc))
     {
       uint32_t lavcodec_mpeg = 0;
@@ -382,7 +416,7 @@ if (fourCC::check (fcc, (uint8_t *) "FFV1"))
   printf ("\n using invalid codec for \n");
   fourCC::print (fcc);
 
-  return (decoders *) (new decoders (w, h));
+  return (decoders *) (new decoderEmpty (w, h));
 
 
 
