@@ -22,43 +22,39 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <math.h>
-
-#ifdef USE_FFMPEG
-#include <ADM_assert.h>
 
+#include "ADM_assert.h"
+#include "prefs.h"
 #include "ADM_lavcodec.h"
-#include "ADM_library/default.h"
-
-#include "ADM_colorspace/colorspace.h"
+#include "ADM_utilities/default.h"
 
 #include "ADM_codecs/ADM_codec.h"
-
 #include "ADM_codecs/ADM_ffmp43.h"
-//#include "ADM_gui/GUI_MPP.h"
-
 #include "ADM_toolkit/toolkit.hxx"
 
-#include "ADM_toolkit/ADM_debugID.h"
+#include "ADM_osSupport/ADM_debugID.h"
 #define MODULE_NAME  MODULE_CODEC
-#include "ADM_toolkit/ADM_debug.h"
-#include "ADM_toolkit/ADM_cpuCap.h"
+#include "ADM_osSupport/ADM_debug.h"
+#include "ADM_video/ADM_videoInfoExtractor.h"
+
+extern int ADM_cpu_num_processors(void);
 
-//****************************
 #define WRAP_Open(x) \
 {\
 AVCodec *codec=avcodec_find_decoder(x);\
-if(!codec) {GUI_Alert(_("Internal error finding codec"#x));ADM_assert(0);} \
+if(!codec) {GUI_Alert(QT_TR_NOOP("Internal error finding codec"#x));ADM_assert(0);} \
   codecId=x; \
+  _context->workaround_bugs=1*FF_BUG_AUTODETECT +1*FF_BUG_NO_PADDING;/**/ \
+  _context->error_concealment=3; \
   if (avcodec_open(_context, codec) < 0)  \
                       { \
-                                        printf(" Decoder init: Lavcodec :"#x" video decoder failed!\n"); \
+                                        printf("[lavc] Decoder init: "#x" video decoder failed!\n"); \
                                         GUI_Alert("Internal error opening "#x); \
                                         ADM_assert(0); \
                                 } \
                                 else \
                                 { \
-                                        printf(" Decoder init: lavcodec "#x" video decoder initialized!\n"); \
+                                        printf("[lavc] Decoder init: "#x" video decoder initialized!\n"); \
                                 } \
 }
 //****************************
@@ -71,9 +67,8 @@ extern "C"
 
 uint8_t decoderFF::clonePic (AVFrame * src, ADMImage * out)
 {
-  uint32_t
-    u,
-    v;
+  uint32_t    u,v;
+  ADM_assert(out->_isRef);
   out->_planes[0] = (uint8_t *) src->data[0];
   out->_planeStride[0] = src->linesize[0];
   if (_swapUV)
@@ -97,7 +92,7 @@ uint8_t decoderFF::clonePic (AVFrame * src, ADMImage * out)
   out->flags = frameType ();
 
   // Quant ?
-  if (src->qstride && src->qscale_table)
+  if (src->qstride && src->qscale_table && codecId != CODEC_ID_H264)
     {
       out->quant = (uint8_t *) src->qscale_table;
       out->_qStride = src->qstride;
@@ -109,24 +104,30 @@ uint8_t decoderFF::clonePic (AVFrame * src, ADMImage * out)
       out->_qSize = out->_qStride = 0;
       out->quant = NULL;
     }
-
+  out->demuxerFrameno=(uint32_t) (uint64_t)(src->opaque);
 }
 void
 decoderFF::decoderMultiThread (void)
 {
-  uint32_t nbThread = 0;
+  uint32_t threads = 0;
 
-  nbThread = ADM_useNbThreads ();
-  if (nbThread)
-    {
-      printf ("[codec]Enabling MT decoder with %u threads\n", nbThread);
-      if (0 > avcodec_thread_init (_context, nbThread))
-	{
-	  printf ("[codec]Failed!!\n");
-	  return;
-	}
-      _usingMT = 1;
-    }
+  prefs->get(FEATURE_THREADING_LAVC, &threads);
+
+  if (threads == 0)
+	  threads = ADM_cpu_num_processors();
+
+  if (threads == 1)
+	  threads = 0;
+
+  if (threads)
+  {
+      printf ("[lavc] Enabling MT decoder with %u threads\n", threads);
+
+      if (avcodec_thread_init (_context, threads) == -1)
+	      printf ("[lavc] Failed!!\n");
+	  else
+          _usingMT = 1;
+  }
 }
 uint8_t decoderFF::getPARWidth (void)
 {
@@ -216,9 +217,10 @@ decoderFF::decoderFF (uint32_t w, uint32_t h):decoders (w, h)
   _showMv = 0;
 #define FF_SHOW		(FF_DEBUG_VIS_MV_P_FOR+	FF_DEBUG_VIS_MV_B_FOR+FF_DEBUG_VIS_MV_B_BACK)
 //#define FF_SHOW               (FF_DEBUG_VIS_MV_P_FOR)
-  printf ("FFMpeg build : %d\n", LIBAVCODEC_BUILD);
+  printf ("[lavc] Build: %d\n", LIBAVCODEC_BUILD);
   _context->debug_mv |= FF_SHOW;
   _context->debug |= FF_DEBUG_VIS_MB_TYPE + FF_DEBUG_VIS_QP;
+  
 }
 
 //_____________________________________________________
@@ -227,7 +229,7 @@ decoderFF::~decoderFF ()
 {
   if (_usingMT)
     {
-      printf ("[decoder] Killing decoding threads\n");
+      printf ("[lavc] Killing decoding threads\n");
       avcodec_thread_free (_context);
       _usingMT = 0;
     }
@@ -235,7 +237,7 @@ decoderFF::~decoderFF ()
   avcodec_close (_context);
   ADM_dealloc (_context);
   delete[]_internalBuffer;
-  printf ("FF base destroyed\n");
+  printf ("[lavc] Destroyed\n");
 }
 
 //-------------------------------
@@ -246,7 +248,7 @@ uint32_t decoderFF::frameType (void)
 
   AVFrame *
     target;
-#define SET(x) {flag=x;aprintf(" Frame is %s\n",#x);}
+#define SET(x) {flag=x;aprintf("Frame is %s\n",#x);}
 
 
   target = &_frame;
@@ -255,7 +257,7 @@ uint32_t decoderFF::frameType (void)
     case FF_B_TYPE:
       SET (AVI_B_FRAME);
       if (target->key_frame)
-	aprintf ("\n But keyframe is  set\n");
+	aprintf ("\n But keyframe is set\n");
       break;
 
     case FF_I_TYPE:
@@ -275,7 +277,7 @@ uint32_t decoderFF::frameType (void)
     case FF_P_TYPE:
       SET (AVI_P_FRAME);
       if (target->key_frame)
-	aprintf ("\n But keyframe is  set\n");
+	aprintf ("\n But keyframe is set\n");
       break;
     default:
 //                              printf("\n OOops XXX frame ?\n");
@@ -289,19 +291,17 @@ uint8_t decoderFF::decodeHeaderOnly (void)
     _context->hurry_up = 4;
   else
     _context->hurry_up = 5;
-  printf ("\n FFmpeg: Hurry up\n");
+  printf ("\n[lavc] Hurry up\n");
   return 1;
 }
 uint8_t decoderFF::decodeFull (void)
 {
   _context->hurry_up = 0;
-  printf ("\n FFmpeg: full decoding\n");
+  printf ("\n[lavc] full decoding\n");
   return 1;
 }
 
-uint8_t
-  decoderFF::uncompress (uint8_t * in, ADMImage * out, uint32_t len,
-			 uint32_t * flagz)
+uint8_t   decoderFF::uncompress (ADMCompressedImage * in, ADMImage * out)
 {
   int got_picture = 0;
   uint8_t *oBuff[3];
@@ -321,31 +321,32 @@ uint8_t
       _context->debug &= ~(FF_DEBUG_VIS_MB_TYPE + FF_DEBUG_VIS_QP);
     }
 
-  if (len == 0 && !_allowNull)	// Null frame, silently skipped
+    
+    
+  if (in->dataLength == 0 && !_allowNull)	// Null frame, silently skipped
     {
-      if (flagz)
-	*flagz = AVI_KEY_FRAME;
-      printf ("\n ff4: null frame\n");
+      
+      printf ("\n[lavc] null frame\n");
       {
 	// search the last image
 	if (_context->coded_frame && _context->coded_frame->data)
 	  {
 	    clonePic (_context->coded_frame, out);
-	    if (flagz)
-	      *flagz = out->flags;
 	  }
 	else
 	  out->_noPicture = 1;
       }
       return 1;
     }
-
-  ret = avcodec_decode_video (_context, &_frame, &got_picture, in, len);
+  
+  _frame.opaque=(void *)in->demuxerFrameNo;
+  
+  ret = avcodec_decode_video (_context, &_frame, &got_picture, in->data, in->dataLength);
   out->_qStride = 0;		//Default = no quant
   if (0 > ret && !_context->hurry_up)
     {
-      printf ("\n error in FFMP43/mpeg4!\n");
-      printf ("Err: %d, size :%d\n", ret, len);
+      printf ("\n[lavc] error in FFMP43/mpeg4!\n");
+      printf ("[lavc] Err: %d, size :%d\n", ret, in->dataLength);
       return 0;
     }
   if (!got_picture && !_context->hurry_up)
@@ -353,15 +354,13 @@ uint8_t
       // Some encoder code a vop header with the 
       // vop flag set to 0
       // it is meant to mean frame skipped but very dubious
-      if (len <= 8 && codecId == CODEC_ID_MPEG4)
+      if (in->dataLength <= 8 && codecId == CODEC_ID_MPEG4)
 	{
-	  printf ("Probably pseudo black frame...\n");
+	  printf ("[lavc] Probably pseudo black frame...\n");
 	  out->_Qp = 2;
 	  out->flags = 0;	// assume P ?
 
 	  clonePic (_context->coded_frame, out);
-	  if (flagz)
-	    *flagz = out->flags;
 	  return 1;
 	}
       // allow null means we allow null frame in and so potentially
@@ -369,8 +368,7 @@ uint8_t
       // in that case silently fill with black and returns it as KF
       if (_allowNull)
 	{
-	  if (flagz)
-	    *flagz = AVI_KEY_FRAME;
+	  out->flags = AVI_KEY_FRAME;
 	  if (!_refCopy)
 	    {
 	      memset (out->data, 0, _w * _h);
@@ -380,22 +378,19 @@ uint8_t
 	    {
 	      out->_noPicture = 1;
 	    }
-	  printf ("\n ignoring got pict ==0\n");
+	  printf ("\n[lavc] ignoring got pict ==0\n");
 	  return 1;
 
 	}
-      printf ("Err: %d, size :%d\n", ret, len);
-      printf ("\n error in FFMP43/mpeg4!: got picture \n");
+      printf ("[lavc] Err: %d, size: %d\n", ret, in->dataLength);
+      printf ("\n[lavc] error in FFMP43/mpeg4!: got picture\n");
       //GUI_Alert("Please retry with misc->Turbo off");
       //return 1;
       return 0;
     }
   if (_context->hurry_up)
     {
-      if (flagz)
-	{
-	  *flagz = frameType ();
-	}
+      out->flags = frameType ();
       return 1;
     }
 
@@ -410,6 +405,11 @@ uint8_t
       out->_colorspace = ADM_COLOR_YUV422;
       break;
 
+    case PIX_FMT_YUV444P:
+    case PIX_FMT_YUVJ444P:
+      out->_colorspace = ADM_COLOR_YUV444;
+      break;
+
     case PIX_FMT_YUV420P:
     case PIX_FMT_YUVJ420P:
       // Default is YV12 or I420
@@ -417,23 +417,27 @@ uint8_t
       // we do it or not
       out->_colorspace = ADM_COLOR_YV12;
       break;
-      break;
+
     case PIX_FMT_RGBA32:
       out->_colorspace = ADM_COLOR_RGB32A;
       break;
     case PIX_FMT_RGB555:
-      out->_colorspace = ADM_COLOR_BGR555;
+      out->_colorspace = ADM_COLOR_RGB555;
       break;
     default:
-      printf ("\n Unhandled colorspace:%d\n", _context->pix_fmt);
+      printf ("[lavc] Unhandled colorspace: %d\n", _context->pix_fmt);
       return 0;
     }
-  clonePic (&_frame, out);
-  if (flagz)
-    *flagz = out->flags;
+    clonePic (&_frame, out);
+    #if 0
+    printf("[lavc] Frame bitstream order: %u, display order %u Incoming: %u outgoing: %u\n",_frame.coded_picture_number,_frame.display_picture_number,
+         in->demuxerFrameNo,out->demuxerFrameno);
+    printf("[lavc] in flags: %x out flags: %x\n",in->flags, out->flags);
+ #endif 
   return 1;
 }
 
+#define LOWDELAY() _context->flags |= CODEC_FLAG_LOW_DELAY
 
 
 decoderFFDiv3::decoderFFDiv3 (uint32_t w, uint32_t h):decoderFF (w, h)
@@ -444,22 +448,25 @@ decoderFFDiv3::decoderFFDiv3 (uint32_t w, uint32_t h):decoderFF (w, h)
 decoderFFMpeg4VopPacked::decoderFFMpeg4VopPacked (uint32_t w, uint32_t h):decoderFF (w,
 	   h)
 {
-// force low delay as avidemux don't handle B-frames
-
+/* In that case, we cannot use lowdelay...*/
   _refCopy = 1;			// YUV420 only
   _allowNull = 1;
   decoderMultiThread ();
   WRAP_Open (CODEC_ID_MPEG4);
+  printf("[lavc] Non low delay mpeg4 decoder initialized\n");
 }
-decoderFFMpeg4::decoderFFMpeg4 (uint32_t w, uint32_t h, uint32_t l, uint8_t * d):decoderFF (w,
+decoderFFMpeg4::decoderFFMpeg4 (uint32_t w, uint32_t h, uint32_t fcc,uint32_t l, uint8_t * d):decoderFF (w,
 	   h)
 {
 // force low delay as avidemux don't handle B-frames
-  printf ("Using %d bytes of extradata for MPEG4 decoder\n", l);
-  _context->flags |= CODEC_FLAG_LOW_DELAY;
+  LOWDELAY();
+  printf ("[lavc] Using %d bytes of extradata for MPEG4 decoder\n", l);
+  
   _refCopy = 1;			// YUV420 only
-  _context->extradata = (void *) d;
+  _context->extradata = (uint8_t *) d;
   _context->extradata_size = (int) l;
+  _context->codec_tag=fcc;
+  _context->stream_codec_tag=fcc;
   decoderMultiThread ();
   //  _context->flags|=FF_DEBUG_VIS_MV;
   WRAP_Open (CODEC_ID_MPEG4);
@@ -467,7 +474,7 @@ decoderFFMpeg4::decoderFFMpeg4 (uint32_t w, uint32_t h, uint32_t l, uint8_t * d)
 decoderFFDV::decoderFFDV (uint32_t w, uint32_t h, uint32_t l, uint8_t * d):decoderFF (w,
 	   h)
 {
-  _context->extradata = (void *) d;
+  _context->extradata = (uint8_t *) d;
   _context->extradata_size = (int) l;
   WRAP_Open (CODEC_ID_DVVIDEO);
 
@@ -483,7 +490,7 @@ decoderFFMpeg12::decoderFFMpeg12 (uint32_t w, uint32_t h, uint32_t extraLen, uin
 {
   int
     got_picture = 0;
-  _context->flags |= CODEC_FLAG_LOW_DELAY;
+  LOWDELAY();
   _refCopy = 1;			// YUV420 only
   decoderMultiThread ();
   WRAP_Open (CODEC_ID_MPEG2VIDEO);
@@ -494,8 +501,8 @@ decoderFFSVQ3::decoderFFSVQ3 (uint32_t w, uint32_t h, uint32_t extraLen, uint8_t
   int
     got_picture = 0;
 
-  _context->flags |= CODEC_FLAG_LOW_DELAY;
-  _context->extradata = (void *) extraData;
+  LOWDELAY();
+  _context->extradata = (uint8_t *) extraData;
   _context->extradata_size = (int) extraLen;
   WRAP_Open (CODEC_ID_SVQ3);
 }
@@ -511,12 +518,13 @@ decoderFFV1::decoderFFV1 (uint32_t w, uint32_t h):decoderFF (w, h)
   _refCopy = 1;			// YUV420 only
   WRAP_Open (CODEC_ID_FFV1);
 }
-decoderFF_ffhuff::decoderFF_ffhuff (uint32_t w, uint32_t h, uint32_t l, uint8_t * d):decoderFF (w,
+decoderFF_ffhuff::decoderFF_ffhuff (uint32_t w, uint32_t h, uint32_t l, uint8_t * d,uint32_t bpp):decoderFF (w,
 	   h)
 {
-  _context->extradata = (void *) d;
+  _context->extradata = (uint8_t *) d;
   _context->extradata_size = (int) l;
-  printf ("FFhuff: We have :%d bytes of extra data\n", l);
+  _context->bits_per_sample=bpp;
+  printf ("[lavc] FFhuff: We have %d bytes of extra data\n", l);
   WRAP_Open (CODEC_ID_FFVHUFF);
 
 }
@@ -525,26 +533,44 @@ decoderFFH264::decoderFFH264 (uint32_t w, uint32_t h, uint32_t l, uint8_t * d, u
 {
   _lowDelay=lowdelay;
   _refCopy = 1;			// YUV420 only
-  _context->extradata = (void *) d;
+  _context->extradata = (uint8_t *) d;
   _context->extradata_size = (int) l;
   if(lowdelay)
-    _context->flags |= CODEC_FLAG_LOW_DELAY;
-  printf ("Initializing lavcodec H264 decoder with %d extradata\n", l);
+    LOWDELAY();
+  printf ("[lavc] Initializing H264 decoder with %d extradata\n", l);
   WRAP_Open (CODEC_ID_H264);
 
 }
-decoderFFhuff::decoderFFhuff (uint32_t w, uint32_t h, uint32_t l, uint8_t * d):decoderFF (w,
+//*********************
+extern "C" {int av_getAVCStreamInfo(AVCodecContext *avctx, uint32_t  *nalSize, uint32_t *isAvc);}
+
+uint8_t   decoderFFH264::uncompress (ADMCompressedImage * in, ADMImage * out)
+{
+  if(!_context->hurry_up) return decoderFF::uncompress (in, out);
+  
+  uint32_t nalSize, isAvc;
+  av_getAVCStreamInfo(_context,&nalSize,&isAvc);
+  if(isAvc)
+  {
+      return extractH264FrameType(nalSize, in->data,in->dataLength,&(out->flags));
+  }else
+  {
+    return extractH264FrameType_startCode(nalSize, in->data,in->dataLength,&(out->flags));
+  }
+}
+//*********************
+decoderFFhuff::decoderFFhuff (uint32_t w, uint32_t h, uint32_t l, uint8_t * d,uint32_t bpp):decoderFF (w,
 	   h)
 {
-  _context->extradata = (void *) d;
+  _context->extradata = (uint8_t *) d;
   _context->extradata_size = (int) l;
-
+  _context->bits_per_sample = bpp;
   WRAP_Open (CODEC_ID_HUFFYUV);
 }
 decoderFFWMV2::decoderFFWMV2 (uint32_t w, uint32_t h, uint32_t l, uint8_t * d):decoderFF (w,
 	   h)
 {
-  _context->extradata = (void *) d;
+  _context->extradata = (uint8_t *) d;
   _context->extradata_size = (int) l;
 
   WRAP_Open (CODEC_ID_WMV2);
@@ -553,7 +579,7 @@ decoderFFWMV2::decoderFFWMV2 (uint32_t w, uint32_t h, uint32_t l, uint8_t * d):d
 decoderFFWMV1::decoderFFWMV1 (uint32_t w, uint32_t h, uint32_t l, uint8_t * d):decoderFF (w,
 	   h)
 {
-  _context->extradata = (void *) d;
+  _context->extradata = (uint8_t *) d;
   _context->extradata_size = (int) l;
 
   WRAP_Open (CODEC_ID_WMV1);
@@ -563,16 +589,25 @@ decoderFFWMV1::decoderFFWMV1 (uint32_t w, uint32_t h, uint32_t l, uint8_t * d):d
 decoderFFWMV3::decoderFFWMV3 (uint32_t w, uint32_t h, uint32_t l, uint8_t * d):decoderFF (w,
 	   h)
 {
-  _context->extradata = (void *) d;
+  _context->extradata = (uint8_t *) d;
   _context->extradata_size = (int) l;
 
   WRAP_Open (CODEC_ID_WMV3);
 
 }
+
+decoderFFVC1::decoderFFVC1(uint32_t w, uint32_t h, uint32_t l, uint8_t * d) : decoderFF(w, h)
+{
+  _context->extradata = (uint8_t *) d;
+  _context->extradata_size = (int) l;
+
+  WRAP_Open (CODEC_ID_VC1);
+}
+
 decoderFFcyuv::decoderFFcyuv (uint32_t w, uint32_t h, uint32_t l, uint8_t * d):decoderFF (w,
 	   h)
 {
-  _context->extradata = (void *) d;
+  _context->extradata = (uint8_t *) d;
   _context->extradata_size = (int) l;
 
   WRAP_Open (CODEC_ID_CYUV);
@@ -584,7 +619,7 @@ decoderFFMJPEG::decoderFFMJPEG (uint32_t w, uint32_t h):decoderFF (w, h)
 decoderFFTheora::decoderFFTheora (uint32_t w, uint32_t h, uint32_t l, uint8_t * d):decoderFF (w,
 	   h)
 {
-  _context->extradata = (void *) d;
+  _context->extradata = (uint8_t *) d;
   _context->extradata_size = (int) l;
   WRAP_Open (CODEC_ID_THEORA);
 }
@@ -592,12 +627,119 @@ decoderSnow::decoderSnow (uint32_t w, uint32_t h):decoderFF (w, h)
 {
   WRAP_Open (CODEC_ID_SNOW);
 }
-decoderCamtasia::decoderCamtasia (uint32_t w, uint32_t h, uint32_t bpp):decoderFF (w,
-	   h)
+//*************
+decoderCamtasia::decoderCamtasia (uint32_t w, uint32_t h,uint32_t bpp):decoderFF (w,  h)
 {
   _context->bits_per_sample = bpp;
   WRAP_Open (CODEC_ID_TSCC);
 }
+//*************
+decoderFFCinepak::decoderFFCinepak (uint32_t w, uint32_t h, uint32_t l, uint8_t * d):decoderFF (w,	   h)
+{
+  WRAP_Open (CODEC_ID_CINEPAK);
+}
+//*************
+decoderFFCRAM::decoderFFCRAM (uint32_t w, uint32_t h, uint32_t l, uint8_t * d):decoderFF (w,	   h)
+{
+  WRAP_Open (CODEC_ID_MSVIDEO1);
+}
+//*************
+decoderFFVP6F::decoderFFVP6F (uint32_t w, uint32_t h, uint32_t l, uint8_t * d):decoderFF (w,	   h)
+{
+  WRAP_Open (CODEC_ID_VP6F);
+}
+//************
+decoderFFFLV1::decoderFFFLV1 (uint32_t w, uint32_t h, uint32_t l, uint8_t * d):decoderFF (w,	   h)
+{
+  WRAP_Open (CODEC_ID_FLV1);
+}
+decoderFFAMV::decoderFFAMV (uint32_t w, uint32_t h, uint32_t l, uint8_t * d):decoderFF (w,   h)
+{
+  WRAP_Open (CODEC_ID_AMV);
+  //_context->codec_id=CODEC_ID_AMV;
+}
+decoderFFMjpegB::decoderFFMjpegB (uint32_t w, uint32_t h, uint32_t l, uint8_t * d):decoderFF (w,   h)
+{
+  WRAP_Open (CODEC_ID_MJPEGB);
+  //_context->codec_id=CODEC_ID_AMV;
+}
+decoderFFDVBSub::decoderFFDVBSub (uint32_t w, uint32_t h, uint32_t l, uint8_t * d):decoderFF (w,	   h)
+{
+  _context->sub_id=1;
+  WRAP_Open (CODEC_ID_DVB_SUBTITLE);
+}
+//*********************
+/**
+    \fn decoderFFSubs
+    \brief Constructor for DVB subtitles...
+*/
+
+decoderFFSubs::decoderFFSubs (uint32_t subid)
+{
+  _context = avcodec_alloc_context ();
+  codecId= CODEC_ID_DVB_SUBTITLE;
+  subId=subid;
+  _context->sub_id=subId;
+  WRAP_Open (CODEC_ID_DVB_SUBTITLE);
+}
+decoderFFSubs:: ~ decoderFFSubs ()
+{
+  avcodec_close (_context);
+  ADM_dealloc (_context);
+  _context=NULL;
+  
+}
+
+uint8_t decoderFFSubs::uncompress (ADMCompressedImage * in, AVSubtitle * out)
+{
+  int ret=0;
+  int got_picture=0;
+  ret=avcodec_decode_subtitle(_context, out,
+                            &got_picture,
+                            in->data, in->dataLength); 
+     if(ret<0) 
+     {
+        printf("[lavc] FFSUB Error %d\n",ret);
+        return 0; 
+     }
+     return 1;
+}
 
 
+//***************
+extern uint8_t  lavformat_init(void);
+extern void     avcodec_init(void );
+extern  void    avcodec_register_all(void );
+extern "C"
+{
+  void adm_lavLogCallback(void  *instance, int level, const char* fmt, va_list list);
+}
+/**
+    \fn ADM_lavInit
+    \brief Init both lavcodec and lavformat
+*/
+void ADM_lavInit(void)
+{
+    avcodec_init();
+    avcodec_register_all();
+    lavformat_init();
+    av_log_set_callback(adm_lavLogCallback);
+#ifdef ADM_DEBUG
+  //  av_log_set_level(AV_LOG_DEBUG);
 #endif
+
+}
+void adm_lavLogCallback(void  *instance, int level, const char* fmt, va_list list)
+{
+    if(level>1) return;
+    char buf[256];
+  
+    vsnprintf(buf, sizeof(buf), fmt, list);
+    printf("[lavc] %s\n",buf);
+}
+
+void ADM_lavDestroy(void)
+{
+	av_free_static();
+}
+// EOF
