@@ -18,8 +18,21 @@
  *                                                                         *
  ***************************************************************************/
 #ifdef USE_FFMPEG
+#include "ADM_lavcodec.h"
+class decoderFFSubs
+{
+  protected:
+     int      codecId;
+     uint32_t subId;
+     AVCodecContext *_context;
+  public:
 
+    decoderFFSubs (uint32_t subId);
+    virtual ~ decoderFFSubs ();
+    virtual uint8_t uncompress (ADMCompressedImage * in, AVSubtitle * out); 
+};
 
+/****************************/
 class decoderFF:public decoders
 {
 protected:
@@ -45,8 +58,7 @@ public:
   {
     return 1;
   }
-  virtual uint8_t uncompress (uint8_t * in, ADMImage * out,
-			      uint32_t len, uint32_t * flag = NULL);
+  virtual uint8_t uncompress (ADMCompressedImage * in, ADMImage * out);
   virtual void setParam (void);
   virtual uint8_t bFramePossible (void)
   {
@@ -95,7 +107,7 @@ protected:
 
 
 public:
-  decoderFFMpeg4 (uint32_t w, uint32_t h, uint32_t l, uint8_t * d);
+  decoderFFMpeg4 (uint32_t w, uint32_t h, uint32_t fcc,uint32_t l, uint8_t * d);
   // mpeg4 can have B-frame
   virtual uint8_t bFramePossible (void)
   {
@@ -169,6 +181,7 @@ public:
   {
       return _lowDelay;
   }
+  uint8_t   uncompress (ADMCompressedImage * in, ADMImage * out);
 
 };
 class decoderFFhuff:public decoderFF
@@ -177,7 +190,7 @@ protected:
 
 
 public:
-  decoderFFhuff (uint32_t w, uint32_t h, uint32_t l, uint8_t * d);
+  decoderFFhuff (uint32_t w, uint32_t h, uint32_t l, uint8_t * d,uint32_t bpp);
 
 };
 class decoderFF_ffhuff:public decoderFF
@@ -186,7 +199,7 @@ protected:
 
 
 public:
-  decoderFF_ffhuff (uint32_t w, uint32_t h, uint32_t l, uint8_t * d);
+  decoderFF_ffhuff (uint32_t w, uint32_t h, uint32_t l, uint8_t * d,uint32_t bpp);
 
 };
 class decoderFFWMV2:public decoderFF
@@ -217,6 +230,17 @@ public:
   decoderFFWMV3 (uint32_t w, uint32_t h, uint32_t l, uint8_t * d);
 
 };
+
+class decoderFFVC1:public decoderFF
+{
+protected:
+
+
+public:
+  decoderFFVC1 (uint32_t w, uint32_t h, uint32_t l, uint8_t * d);
+
+};
+
 class decoderFFV1:public decoderFF
 {
 protected:
@@ -259,7 +283,7 @@ protected:
 
 
 public:
-  decoderCamtasia (uint32_t w, uint32_t h, uint32_t bpp);
+  decoderCamtasia (uint32_t w, uint32_t h,uint32_t bpp);
 
 };
 class decoderFFTheora:public decoderFF
@@ -272,4 +296,53 @@ public:
 
 };
 
+class decoderFFCinepak:public decoderFF
+{
+protected:
+
+
+public:
+  decoderFFCinepak (uint32_t w, uint32_t h, uint32_t l, uint8_t * d);
+
+};
+class decoderFFCRAM:public decoderFF
+{
+protected:
+
+
+public:
+  decoderFFCRAM (uint32_t w, uint32_t h, uint32_t l, uint8_t * d);
+
+};
+class decoderFFVP6F:public decoderFF
+{
+protected:
+public:
+  decoderFFVP6F (uint32_t w, uint32_t h, uint32_t l, uint8_t * d);
+};
+class decoderFFFLV1:public decoderFF
+{
+protected:
+public:
+  decoderFFFLV1 (uint32_t w, uint32_t h, uint32_t l, uint8_t * d);
+};
+class decoderFFDVBSub:public decoderFF
+{
+protected:
+public:
+  decoderFFDVBSub (uint32_t w, uint32_t h, uint32_t l, uint8_t * d);
+};
+class decoderFFAMV:public decoderFF
+{
+protected:
+public:
+  decoderFFAMV (uint32_t w, uint32_t h, uint32_t l, uint8_t * d);
+};
+class decoderFFMjpegB:public decoderFF
+{
+protected:
+public:
+  decoderFFMjpegB (uint32_t w, uint32_t h, uint32_t l, uint8_t * d);
+};
+
 #endif
