@@ -3,7 +3,7 @@
                              -------------------
 
 	Encoder for ffmpeg
-	Rever-enginereed from mplayer & transcode
+	Reverse enginereed from mplayer & transcode
 		
 
     begin                : Tue Sep 10 2002
@@ -20,45 +20,42 @@
  *                                                                         *
  ***************************************************************************/
 #include "config.h"
+
+
+
+#define __STDC_CONSTANT_MACROS // Lavcodec crap
+
 #include <stdio.h>
 #include <stdlib.h>
-
 #include <string.h>
 #include <math.h>
 
-
-#ifdef USE_FFMPEG
 #include "ADM_lavcodec.h"
-
 #include "avi_vars.h"
-#include "prototype.h"
-
-
-#include "ADM_colorspace/colorspace.h"
-#include "ADM_codecs/ADM_divxEncode.h"
-
 #include "ADM_toolkit/toolkit.hxx"
-#include <ADM_assert.h>
+#include "ADM_assert.h"
 #include "ADM_codecs/ADM_ffmpeg.h"
-#include "ADM_toolkit/ADM_cpuCap.h"
+#include "ADM_osSupport/ADM_cpuCap.h"
+#include "prefs.h"
+
 //#define TEST_NOB 1
 
+extern int ADM_cpu_num_processors(void);
 static char LogName[500];
 
 #define WRAP_Open(x) \
 {\
 AVCodec *codec=avcodec_find_encoder(x);\
-if(!codec) {GUI_Alert(_("Internal error opening codec"#x));ADM_assert(0);} \
+if(!codec) {GUI_Alert(QT_TR_NOOP("Internal error opening codec"#x));ADM_assert(0);} \
   res=avcodec_open(_context, codec); \
-  if(res<0) {GUI_Alert(_("Internal error with context for  codec"#x".\n Did you use too low / too high target for 2 pass ?"));return 0;} \
+  if(res<0) {GUI_Alert(QT_TR_NOOP("Internal error with context for  codec"#x".\n Did you use too low / too high target for 2 pass ?"));return 0;} \
 }
 /*****************************************/
 uint8_t ffmpegEncoder::stopEncoder(void)
 {
-    printf("[lavcodec] stopEncoder (%x)\n",_context);
-    if (_init)
+    printf("[lavc] stopEncoder (%x)\n",_context);
+    if (_context)
     {
-        _init = 0;
         avcodec_close (_context);
         ADM_dealloc (_context);
         _context = NULL;
@@ -68,7 +65,7 @@ uint8_t ffmpegEncoder::stopEncoder(void)
 /*****************************************/
 ffmpegEncoderCQ::~ffmpegEncoderCQ ()
   {
-    printf("Deleting ffmpegCQencoder\n");
+    printf("[LAVCODEC]Deleting ffmpegCQencoder\n");
     //stopEncoder ();
     if (_statfile)
       {
@@ -91,11 +88,11 @@ void ffmpegEncoder::postAmble (ADMBitstream * out, uint32_t sz)
 }
 //static myENC_RESULT res;
 /*****************************************/
-ffmpegEncoder::ffmpegEncoder (uint32_t width, uint32_t height, FF_CODEC_ID id):encoder (width,
+ffmpegEncoder::ffmpegEncoder (uint32_t width, uint32_t height, FF_CODEC_ID id,PixelFormat format):encoder (width,
 	 height)
 {
-  printf ("\n Build : %d \n", LIBAVCODEC_BUILD);
-
+  printf ("[LAVCODEC]Build: %d, colorspace :%x\n", LIBAVCODEC_BUILD,format);
+  _targetColorSpace=format;//PIX_FMT_YUV420P
   _id = id;
   _swap = 0;
   _context = NULL;
@@ -108,10 +105,9 @@ ffmpegEncoder::ffmpegEncoder (uint32_t width, uint32_t height, FF_CODEC_ID id):e
   _frame.pts = AV_NOPTS_VALUE;
   _context->width = _w;
   _context->height = _h;
-  _frame.linesize[0] = _w;
-  _frame.linesize[1] = _w >> 1;
-  _frame.linesize[2] = _w >> 1;
+
   _isMT = 0;
+  encodePreamble(NULL);
 
 };
 /*****************************************/
@@ -128,10 +124,10 @@ uint8_t   ffmpegEncoder::encode(ADMImage *in,ADMBitstream *out)
 /*****************************************/
 ffmpegEncoder::~ffmpegEncoder ()
 {
-  printf ("[codec] FF base encoder destroying..\n");
-  if (_isMT)
+  printf ("[lavc] encoder destroying..\n");
+  if (_isMT && _context)
     {
-      printf ("[codec] killing threads\n");
+      printf ("[lavc] killing threads\n");
       avcodec_thread_free (_context);
       _isMT = 0;
     }
@@ -146,22 +142,31 @@ ffmpegEncoder::~ffmpegEncoder ()
 uint8_t
 ffmpegEncoder::encodePreamble (uint8_t * in)
 {
-  _frame.linesize[0] = _w;
-  _frame.linesize[1] = _w >> 1;
-  _frame.linesize[2] = _w >> 1;
-
-/*
-   		It seems ffmpeg likes the u & v to be swapped WTF...
-
-*/
-
-  _frame.data[0] = in;
-  _frame.data[2] = in + _w * _h;
-  _frame.data[1] = in + _w * _h + ((_w * _h) >> 2);
-
   _frame.key_frame = 0;
   _frame.pict_type = 0;
-// No!  _frame.quality = 0;
+
+  switch(_targetColorSpace)
+  {
+    case PIX_FMT_YUV420P:
+        _frame.linesize[0] = _w;
+        _frame.linesize[1] = _w >> 1;
+        _frame.linesize[2] = _w >> 1;
+        _frame.data[0] = in;
+        _frame.data[2] = in + _w * _h;
+        _frame.data[1] = in + _w * _h + ((_w * _h) >> 2);
+        break;
+ case PIX_FMT_YUV422P:
+        _frame.linesize[0] = _w;
+        _frame.linesize[1] = _w >> 1;
+        _frame.linesize[2] = _w >> 1;
+        _frame.data[0] = in;
+        _frame.data[2] = in + _w * _h;
+        _frame.data[1] = in + _w * _h + ((_w * _h) >> 1);
+      
+        break;
+    default:
+      ADM_assert(0);
+  }
   return 1;
 }
 
@@ -205,7 +210,7 @@ ffmpegEncoder::gopMpeg1 (void)
     {
       if (FRAME_FILM == identMovieType (rate))
 	{
-	  printf ("\nPulldown activated...\n");
+	  printf ("[LAVCODEC]Pulldown activated...\n");
 	  _context->flags2 |= CODEC_FLAG2_32_PULLDOWN;
 	}
     }
@@ -214,7 +219,7 @@ ffmpegEncoder::gopMpeg1 (void)
 #else
   _context->max_b_frames = 2;
 #endif
-  printf ("\n Using 2 b frames \n");
+  printf ("[LAVCODEC]Using 2 b frames\n");
   if (_id == FF_MPEG2)
     {
       _context->mpeg_quant = 1;	//1; // Should be mpeg quant 
@@ -227,7 +232,7 @@ ffmpegEncoder::gopMpeg1 (void)
     {
       if (_settings.widescreen)
 	{
-          printf("WideScreen\n");
+          printf("[LAVCODEC]WideScreen\n");
 	  _context->sample_aspect_ratio.num = 16;
 	  _context->sample_aspect_ratio.den = 9;
 	}
@@ -237,7 +242,7 @@ ffmpegEncoder::gopMpeg1 (void)
 	  _context->sample_aspect_ratio.den = 3;
 	}
 
-      _context->rc_max_rate_header = _settings.maxBitrate * 8;	//1800*1000;// 2400 max, 700 min
+      _context->rc_max_rate_header = _settings.maxBitrate * 1000;//1800*1000;// 2400 max, 700 min
       _context->rc_buffer_size_header = _settings.bufferSize * 8 * 1024;
       // If we don't have a maxrate, don't set buffer_size
       if (1 && !_settings.override_ratecontrol)	// FIXME
@@ -280,17 +285,19 @@ ffmpegEncoder::gopMpeg1 (void)
 
   //
   //_context->dsp_mask= FF_MM_FORCE;
-  printf ("Mpeg12 settings:\n____________\n");
-  printf ("FF Max rate   (header) : %lu kbps\n",
+  printf ("[LAVCODEC]Mpeg12 settings:\n____________\n");
+  printf ("[LAVCODEC]FF Max rate   (header) : %lu kbps\n",
 	  (_context->rc_max_rate_header) / 1000);
-  printf ("FF Buffer Size(header) : %lu bits / %lu kB\n",
+  printf ("[LAVCODEC]FF Buffer Size(header) : %lu bits / %lu kB\n",
 	  (_context->rc_buffer_size_header),
 	  _context->rc_buffer_size_header / (8 * 1024));
-  printf ("FF Max rate   (rc) : %lu kbps\n", (_context->rc_max_rate) / 1000);
-  printf ("FF Buffer Size(rc) : %lu bits / %lu kB\n",
+  printf ("[LAVCODEC]FF Max rate   (rc) : %lu kbps\n", (_context->rc_max_rate) / 1000);
+  printf ("[LAVCODEC]FF Buffer Size(rc) : %lu bits / %lu kB\n",
 	  (_context->rc_buffer_size), _context->rc_buffer_size / (8 * 1024));
 
-  printf ("FF GOP Size    : %lu\n", _context->gop_size);
+  printf ("[LAVCODEC]FF GOP Size    : %lu\n", _context->gop_size);
+  printf ("[LAVCODEC]FF Bitrate    : %lu (kb/s)\n", _context->bit_rate/1000);
+  
   return 1;
 }
 
@@ -331,6 +338,9 @@ ffmpegEncoder::initContext (void)
     case FF_H263P:
       WRAP_Open (CODEC_ID_H263P);
       break;
+    case FF_FLV1:
+      WRAP_Open (CODEC_ID_FLV1);
+      break;
     case FF_HUFF:
       WRAP_Open (CODEC_ID_HUFFYUV);
       break;
@@ -346,36 +356,49 @@ ffmpegEncoder::initContext (void)
     case FF_SNOW:
       WRAP_Open (CODEC_ID_SNOW);
       break;
+      
+    case FF_DV:
+      if(_context->width!=720 || _context->height!=576) 
+            return 0; // should be caught by upper layers before going here...
+      WRAP_Open (CODEC_ID_DVVIDEO);
+      break;
+
     default:
       ADM_assert (0);
     }
 
   if (res < 0)
     {
-      printf ("\n Problem opening ffmpeg codec\n");
+      printf ("[lavc] Problem opening codec\n");
       return 0;
     }
   return 1;
 
 }
-void
-ffmpegEncoder::encoderMT (void)
+
+void ffmpegEncoder::encoderMT (void)
 {
-  uint32_t nbThread = 0;
+  uint32_t threads = 0;
 
-  nbThread = ADM_useNbThreads ();
-  if (nbThread )
-    {
-      printf ("[codec]Enabling MT encoder with %u threads\n", nbThread);
-      if (0 > avcodec_thread_init (_context, nbThread))
-	{
-	  printf ("[codec]Failed!!\n");
-	  return;
-	}
-      _isMT = 1;
-    }
+  prefs->get(FEATURE_THREADING_LAVC, &threads);
 
+  if (threads == 0)
+	  threads = ADM_cpu_num_processors();
+
+  if (threads == 1)
+	  threads = 0;
+
+  if (threads)
+  {
+      printf ("[lavc] Enabling MT encoder with %u threads\n", threads);
+
+      if (avcodec_thread_init (_context, threads) == -1)
+	      printf ("[lavc] Failed!!\n");
+	  else
+          _isMT = 1;
+  }
 }
+
 /*
 		Set user selected matrices.
 
@@ -393,7 +416,7 @@ ffmpegEncoder::setGopSize (uint32_t size)
 {
 
   _context->gop_size = size;
-  printf ("\n Gop size is now %d\n", _context->gop_size);
+  printf ("[LAVCODEC]Gop size is now %d\n", _context->gop_size);
   return 1;
 
 }
@@ -418,7 +441,7 @@ ffmpegEncoder::setConfig (FFcodecSetting * set)
 uint8_t
 ffmpegEncoderCQ::init (uint32_t val, uint32_t fps1000, uint8_t vbr)
 {
-
+  printf ("[LAVCODEC] Using Q=%u\n",val); 
   mplayer_init ();
   _qual = val;
   _vbr = vbr;
@@ -459,14 +482,14 @@ uint8_t ffmpegEncoderCQ::encode (ADMImage * in, ADMBitstream * out)
     {
       if (!_statfile)
 	{
-	  printf ("FFmpeg using %s as log file\n", LogName);
+	  printf ("[lavc] using %s as log file\n", LogName);
 	  _statfile = fopen (LogName, "wb");
 	}
 
       if (!_statfile)
 	{
 	  printf
-	    ("\n FF codec : cannot open log file for writing ! (%s)\n",
+	    ("[lavc] cannot open log file for writing! (%s)\n",
 	     LogName);
 	  return 0;
 	}
@@ -500,9 +523,12 @@ uint8_t ffmpegEncoderCBR::init (uint32_t val, uint32_t fps1000)
   {
   1000, fps1000};
 
-  _context->bit_rate = _br;
+  if(_id==FF_MPEG2 || _id==FF_MPEG1)
+	  _context->bit_rate = _br;
+  else
+	  _context->bit_rate = _br*1000;
 
-  printf ("--> br: %lu", _br);
+  printf ("[LAVCODEC] Using  bitrate in context :%lu kbps",_context->bit_rate/1000);
 
   return initContext ();
 
@@ -531,7 +557,7 @@ ffmpegEncoderVBR::init (uint32_t val, uint32_t fps1000)
   uint32_t statSize;
   FILE *_statfile;
 
-  printf ("\n initializing FFmpeg in VBR mode \n");
+  printf ("[lavc] initializing in VBR mode\n");
   _qual = val;
   mplayer_init ();
 
@@ -546,7 +572,7 @@ ffmpegEncoderVBR::init (uint32_t val, uint32_t fps1000)
   _statfile = fopen (LogName, "rb");
   if (!_statfile)
     {
-      printf ("\n internal file does not exists ?\n");
+      printf ("internal file does not exists ?\n");
       return 0;
     }
 
@@ -592,7 +618,7 @@ uint8_t
 ffmpegEncoderVBRExternal::init (uint32_t val, uint32_t fps1000)
 {
 
-  printf ("\n initializing FFmpeg in VBRExternal  mode \n");
+  printf ("[lavc] initializing in VBRExternal mode\n");
   _qual = val;
   mplayer_init ();
 
@@ -628,11 +654,11 @@ ffmpegEncoder::mplayer_init (void)
   /*
      default values : Copy/past from mplayer
    */
-  _context->pix_fmt = PIX_FMT_YUV420P;	//PIX_FMT_YV12;
+  _context->pix_fmt = _targetColorSpace;
 
   if (!_settingsPresence)
     {
-      printf ("\n using FFmpeg default encode settings \n");
+      printf ("[lavc] using default encode settings \n");
       _context->qmin = 2;
       _context->qmax = 31;
       _context->max_b_frames = 0;
@@ -650,7 +676,7 @@ ffmpegEncoder::mplayer_init (void)
     }
   else
     {
-      if (_id == FF_MPEG1 || _id == FF_MPEG2)
+      if (_id == FF_MPEG1 || _id == FF_MPEG2 || _id == FF_FLV1)
 	{
 	  _context->gop_size = _settings.gop_size;
 	}
@@ -658,8 +684,8 @@ ffmpegEncoder::mplayer_init (void)
 	{
 	  _context->gop_size = 250;
 	}
-#define SETX(x) _context->x=_settings.x; printf(#x" : %d\n",_settings.x);
-#define SETX_COND(x) if(_settings.is_##x) {_context->x=_settings.x; printf(#x" : %d\n",_settings.x);} else\
+#define SETX(x) _context->x=_settings.x; printf("[LAVCODEC]"#x" : %d\n",_settings.x);
+#define SETX_COND(x) if(_settings.is_##x) {_context->x=_settings.x; printf("[LAVCODEC]"#x" : %d\n",_settings.x);} else\
 		{ printf(#x" is not activated\n");}
       SETX (me_method);
       SETX (qmin);
@@ -673,9 +699,9 @@ ffmpegEncoder::mplayer_init (void)
 #undef SETX
 #undef SETX_COND
 
-#define SETX(x)  _context->x=_settings.x; printf(#x" : %f\n",_settings.x);
-#define SETX_COND(x)  if(_settings.is_##x) {_context->x=_settings.x; printf(#x" : %f\n",_settings.x);} else  \
-									{printf(#x" No activated\n");}
+#define SETX(x)  _context->x=_settings.x; printf("[LAVCODEC]"#x" : %f\n",_settings.x);
+#define SETX_COND(x)  if(_settings.is_##x) {_context->x=_settings.x; printf("[LAVCODEC]"#x" : %f\n",_settings.x);} else  \
+									{printf("[LAVCODEC]"#x" No activated\n");}
       SETX_COND (lumi_masking);
       SETX_COND (dark_masking);
       SETX (qcompress);
@@ -686,7 +712,7 @@ ffmpegEncoder::mplayer_init (void)
 #undef SETX
 #undef SETX_COND
 
-#define SETX(x) if(_settings.x){ _context->flags|=CODEC_FLAG##x;printf(#x" is set\n");}
+#define SETX(x) if(_settings.x){ _context->flags|=CODEC_FLAG##x;printf("[LAVCODEC]"#x" is set\n");}
       SETX (_GMC);
 
 
@@ -716,7 +742,7 @@ ffmpegEncoder::mplayer_init (void)
 	{
 	  _context->sample_aspect_ratio.num = 16;
 	  _context->sample_aspect_ratio.den = 9;
-	  printf ("16/9 aspect ratio is set.\n");
+	  printf ("[LAVCODEC]16/9 aspect ratio is set.\n");
 
 	}
 #undef SETX
@@ -789,6 +815,53 @@ ffmpegEncoderHuff::init (uint32_t val, uint32_t fps1000, uint8_t vbr)
   return initContext ();
 }
 //__________________________________
+/**
+
+*/
+
+ffmpegEncoderHuff::ffmpegEncoderHuff (uint32_t width, uint32_t height,FF_CODEC_ID id) 
+  :   ffmpegEncoder (width,height, id,PIX_FMT_YUV422P) 
+{
+  // Allocate our resampler & intermediate
+  yuy2=new uint8_t[width*height*2];
+  // And Color converted
+    convert=new ADMColorspace(width,height, ADM_COLOR_YV12,ADM_COLOR_YUV422P);
+}
+/**
+
+*/
+
+ffmpegEncoderHuff::~ffmpegEncoderHuff()
+{
+  if(yuy2)
+  {
+    delete [] yuy2;
+    yuy2=NULL;  
+  }
+  if(convert)
+  {
+   delete convert;
+    convert=NULL; 
+  }
+  stopEncoder ();
+}
+/**
+
+*/
+  uint8_t   ffmpegEncoderHuff::encode(ADMImage *in,ADMBitstream *out)
+{
+    int32_t sz = 0;
+    ADM_assert(out->bufferSize);
+    encodePreamble(yuy2);
+    /* Convert */
+   convert->convert(in->data,yuy2);
+    
+    /***/
+    if ((sz = avcodec_encode_video (_context, out->data, out->bufferSize, &_frame)) < 0)
+        return 0;
+    postAmble(out,sz);
+    return 1;
+}
 //------------------------------
 uint8_t
   ffmpegEncoderFFHuff::init (uint32_t val, uint32_t fps1000, uint8_t vbr)
@@ -810,14 +883,13 @@ uint8_t
   return initContext ();
 }
 
-
 //_______________________________________
 uint8_t
 ffmpegEncoder::getExtraData (uint32_t * l, uint8_t ** d)
 {
   *d = (uint8_t *) _context->extradata;
   *l = _context->extradata_size;
-  printf ("\n We got some extra data  : %lu \n", *l);
+  printf ("[LAVCODEC]We got some extra data: %lu\n", *l);
   if (*l)
     return 1;
 
@@ -843,7 +915,7 @@ ffmpegEncoderFFV1::init (uint32_t val, uint32_t fps1000, uint8_t vbr)
   _context->bit_rate = 0;
   _context->bit_rate_tolerance = 1024 * 8 * 1000;
   _context->gop_size = 250;
-  printf ("FFV1 codec initializing...\n");
+  printf ("[LAVCODEC]FFV1 codec initializing...\n");
   return initContext ();
 }
 
@@ -872,7 +944,7 @@ uint8_t
   _context->bit_rate = 0;
   _context->bit_rate_tolerance = 1024 * 8 * 1000;
   _context->gop_size = 250;
-  printf ("FF Mjpeg codec initializing %d %% -> q =%d...\n", val, _qual);
+  printf ("[LAVCODEC]FF Mjpeg codec initializing %d %% -> q =%d...\n", val, _qual);
   return initContext ();
 }
 
@@ -884,4 +956,4 @@ ffmpegEncoderFFMjpeg::encode (ADMImage * in, ADMBitstream * out)
   _frame.quality = (int) floor (FF_QP2LAMBDA * _qual + 0.5);
   return ffmpegEncoder::encode(in,out);
 }
-#endif
+
