@@ -23,7 +23,7 @@
 #include <ADM_assert.h>
 #include <string.h>
 #include <math.h>
-#include "ADM_library/default.h"
+#include "ADM_utilities/default.h"
 #include "config.h"
 #ifdef USE_MJPEG
 #include "ADM_colorspace/colorspace.h"
