@@ -61,8 +61,7 @@ decoderPng (uint32_t w, uint32_t h);
   
 virtual ~ decoderPng ();
   
-virtual uint8_t uncompress (uint8_t * in, ADMImage * out, uint32_t len,
-			       uint32_t * flag = NULL);
+virtual uint8_t uncompress(ADMCompressedImage * in, ADMImage * out);
   
 uint8_t dontcopy (void)
   {
