@@ -26,7 +26,7 @@
 #include <string.h>
 #include <math.h>
 
-#include "ADM_library/default.h"
+#include "ADM_utilities/default.h"
 
 #include "ADM_codecs/ADM_codec.h"
 //#include "ADM_gui/GUI_xvidparam.h"
