@@ -6,6 +6,8 @@
     begin                : Thu Apr 16 2003
     copyright            : (C) 2002 by mean
     email                : fixounet@free.fr
+    
+ 16 08 2007 : Removed the manual RGB<->BGR, newer swscale can output directly in the correct mode   
  ***************************************************************************/
 
 /***************************************************************************
@@ -17,16 +19,16 @@
  *                                                                         *
  ***************************************************************************/
 #include "config.h"
+
 #include <stdio.h>
 #include <stdlib.h>
-
 #include <string.h>
 
-#include "ADM_library/default.h"
-#include <ADM_assert.h>
+#include "ADM_utilities/default.h"
+#include "ADM_assert.h"
 
 #include "colorspace.h"
-#include "ADM_toolkit/ADM_cpuCap.h"
+#include "ADM_osSupport/ADM_cpuCap.h"
 #if (defined( ARCH_X86)  || defined(ARCH_X86_64))
 extern "C" {
 #include "ADM_lavcodec/avcodec.h"
@@ -56,15 +58,8 @@ extern "C" {
 #endif
 #endif
 
-#ifdef ADM_BIG_ENDIAN
-              #define TARGET_COLORSPACE       PIX_FMT_RGB32 
-//              #define TARGET_COLORSPACE       IMGFMT_ABGR
-//              #define TARGET_COLORSPACE       IMGFMT_RGB32
-//              #define TARGET_COLORSPACE      IMGFMT_BGR32
-#else
-              #define TARGET_COLORSPACE      PIX_FMT_RGB32
-#endif
-
+#define TARGET_COLORSPACE       PIX_FMT_RGB32 
+#define ALTERNATE_COLORSPACE    PIX_FMT_BGR32
 
 void COL_init(void);
 
@@ -104,20 +99,67 @@ void COL_init(void)
 	
     CLEANUP();
     FLAGS();
-    
+    PixelFormat fmt=TARGET_COLORSPACE;
+    if(_inverted) fmt=ALTERNATE_COLORSPACE;
+    if(!ww || !hh) return 0;
+
+	if (_context)
+		sws_freeContext((SwsContext *)_context);
+
 	 _context=(void *)sws_getContext(
-				    		ww,hh,
-						PIX_FMT_YUV420P ,
-		 				ww,hh,
-                                                TARGET_COLORSPACE,
-	    					flags, NULL, NULL,NULL);
+                      ww,hh,
+                      PIX_FMT_YUV420P ,
+                      ww,hh,
+                      fmt,
+                      flags, NULL, NULL,NULL);
 
     if(!_context) ADM_assert(0);
     w=ww;
     h=hh;
     return 1;
 }
+/**
+      \fn invertRGB
+      \brief Do RGBA->BGRA swap
+      howmuch is in pixel, i.e. you have to multiply it by 4 to get the nb of bytes!
+*/
+static void ADM_RGBA2BGRA(uint8_t *ptr, uint32_t howmuch)
+{
+#if ((defined( ARCH_X86)  || defined(ARCH_X86_64)))
+    __asm__(
+                        "1: mov            (%0),%%eax \n"
+                        "bswap          %%eax \n"
+                        "rorl           $8,%%eax \n"
+                        "mov            %%eax,(%0) \n"
+                        "add            $4,%0 \n"
+                        "dec            %1 \n"
+                        "jne            1b\n"
+                :  :"r" (ptr),"r" (howmuch)
+                : "%eax"
+                
+      
+                );
+#else
+uint8_t r,g,b,a;
+                  for(int xx=0;xx<howmuch;xx++)
+                  {
+                      r=ptr[0];
+                      g=ptr[1];
+                      b=ptr[2];
+                      a=ptr[3];
+                      ptr[0]=b;
+                      ptr[1]=g;
+                      ptr[2]=r;
+                      ptr[3]=a;
+                      ptr+=4;
+                  }
+#endif
+}
+/**
+      \fn scale
+      \brief Do the actual colorconversion
 
+*/
  uint8_t ColYuvRgb::scale(uint8_t *src, uint8_t *target)
  {
     uint8_t *srd[3];
@@ -145,7 +187,18 @@ void COL_init(void)
 			ddst[1]=ddst[2]=0;
 
 			sws_scale((SwsContext *)_context,srd,ssrc,0,h,dst,ddst);
+#if 0
+        if(_inverted)
+        {
+                uint8_t r,g,b,a;
+                uint8_t *ptr=target;
+                int pel=h*w;
+                ADM_RGBA2BGRA(ptr,pel);
+        }
+#endif
 #if  defined( ADM_BIG_ENDIAN)
+	if (!_inverted)
+	{
         uint8_t r,g,b,a;
         uint8_t *ptr=target;
         int pel=h*w;
@@ -161,18 +214,86 @@ void COL_init(void)
               ptr[3]=r;
               ptr+=4;
         }
+	}
 #endif
      
         return 1;
  }
 
+/**
+      \fn scale
+      \brief Change colorspace but and put result in the target image , which is bigger
+        Normally not used !
+*/
+ uint8_t ColYuvRgb::scale(uint8_t *src, uint8_t *target,uint32_t startx,uint32_t starty, uint32_t tw,uint32_t th,uint32_t totalW,uint32_t totalH)
+ {
+    uint8_t *srd[3];
+    uint8_t *dst[3];
+    int ssrc[3];
+    int ddst[3];
+
+    ADM_assert(_context);
+    
+    uint32_t page;
+
+    page=tw*th;
+    srd[0]=src;
+    srd[1]=src+page;
+    srd[2]=src+((page*5)>>2);
+
+    ssrc[0]=tw;
+    ssrc[1]=ssrc[2]=tw>>1;
+
+    
+    dst[0]=target+(startx*4)+starty*totalW*4;
+    dst[1]=NULL;
+    dst[2]=NULL;
+    ddst[0]=totalW*4;
+    ddst[1]=ddst[2]=0;
+
+    sws_scale((SwsContext *)_context,srd,ssrc,0,th,dst,ddst);
+#if 0
+    if(_inverted)
+    {
+            uint8_t r,g,b,a;
+            uint8_t *ptr=NULL;
+            int pel=th;
+            for(int yy=0;yy<th;yy++)
+            {
+              ptr=target+(startx*4)+(starty+yy)*totalW*4;;
+              ADM_RGBA2BGRA(ptr,tw);
+            }
+     }
+#endif
+
+#if defined(ADM_BIG_ENDIAN)
+     uint8_t r, g, b, a;
+     uint8_t *ptr = target;
+     int pel = h * w;
+
+     for (int yy = 0; yy < th; yy++)
+     {
+          ptr = target + (startx * 4) + (starty + yy) * totalW * 4;
+          ADM_RGBA2BGRA(ptr, tw);
+     }
+#endif
+
+     return 1;
+ }
+
+ 
+ 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 uint8_t ColYv12Rgb24::reset(uint32_t ww, uint32_t hh)
  {
  int flags=0;
 	CLEANUP();
     FLAGS();
-   
+   if(!ww || !hh) return 0;
+
+	if (_context)
+		sws_freeContext((SwsContext *)_context);
+
 	 _context=(void *)sws_getContext(
 				    		ww,hh,
 						PIX_FMT_YUV420P ,
@@ -232,6 +353,10 @@ uint8_t ColYv12Rgb24::reset(uint32_t ww, uint32_t hh)
                 case ADM_COLOR_RGB16:c=PIX_FMT_RGB565;break;
                 default: ADM_assert(0);
     }
+
+	if (_context)
+		sws_freeContext((SwsContext *)_context);
+
          _context=(void *)sws_getContext(
 				    		ww,hh,
 						c ,
@@ -381,11 +506,12 @@ int c=0;
                 case ADM_COLOR_RGB24:c=PIX_FMT_RGB24;break;
                 case ADM_COLOR_RGB555:c=PIX_FMT_RGB555;break;
                 case ADM_COLOR_BGR555:c=PIX_FMT_BGR555;break;
-                case ADM_COLOR_BGR32A:c=PIX_FMT_BGRA;break;
+                case ADM_COLOR_BGR32A:c=PIX_FMT_BGR32;break;
                 case ADM_COLOR_RGB32A:c=TARGET_COLORSPACE;break;
                 case ADM_COLOR_RGB16:c=PIX_FMT_RGB565;break;
-                case ADM_COLOR_YUV422:c=PIX_FMT_YUV422P;break;
                 case ADM_COLOR_YUV411:c=PIX_FMT_YUV411P;break;
+				case ADM_COLOR_YUV422:c=PIX_FMT_YUV422P;break;
+				case ADM_COLOR_YUV444:c=PIX_FMT_YUV444P;break;
                 default: ADM_assert(0);
     }
          _context=(void *)sws_getContext(
@@ -407,85 +533,80 @@ uint8_t COL_Generic2YV12::clean(void)
                 _context=NULL; 
                 return 1;  
 }
+
 uint8_t COL_Generic2YV12::transform(uint8_t **planes, uint32_t *strides,uint8_t *target)
 {
- uint8_t *srd[3];
-        uint8_t *dst[3];
-        int ssrc[3];
-        int ddst[3];
-        int mul=0;
+	uint8_t *srd[3];
+	uint8_t *dst[3];
+	int ssrc[3];
+	int ddst[3];
+	int mul = 0;
+	uint32_t page = w * h;
 
-        ADM_assert(_context);
+	ADM_assert(_context);
 
-        uint32_t page;
+	if(_colorspace & ADM_COLOR_IS_YUV)
+	{
+		srd[0] = planes[0];
+		srd[1] = planes[2];
+		srd[2] = planes[1];
+		ssrc[0] = strides[0];
+		ssrc[1] = strides[2];
+		ssrc[2] = strides[1];
 
-        page=w*h;
-     
-        if(_colorspace & ADM_COLOR_IS_YUV)
-        {
-                srd[0]=planes[0];
-                srd[1]=planes[1];
-                srd[2]=planes[2];
+		dst[0] = target;
+		dst[2] = target + page;
+		dst[1] = target + ((page * 5) >> 2);
+		ddst[0] = w;
+		ddst[1] = ddst[2] = w >> 1;
 
-                ssrc[0]=strides[0];
-                ssrc[1]=strides[1];
-                ssrc[2]=strides[2];
+		sws_scale((SwsContext *)_context, srd, ssrc, 0, h, dst, ddst);
 
-        
-                dst[0]=target;
-                dst[1]=target+page;
-                dst[2]=target+((page*5)>>2);
-                ddst[0]=w;
-                ddst[1]=ddst[2]=w>>1;
-                sws_scale((SwsContext *)_context,srd,ssrc,0,h,dst,ddst);
-                return 1;
-        }
-        // Else RGB like colorspace
-        switch(_colorspace&0x7FFF )
-        {
-                case ADM_COLOR_RGB16:  
-                case ADM_COLOR_RGB555:  
-                case ADM_COLOR_BGR555:
-                                        mul=2;
-                        break;
-                case ADM_COLOR_BGR24:
-                case ADM_COLOR_RGB24:  mul=3;
-                        break;
-                case ADM_COLOR_BGR32A:
-                case ADM_COLOR_RGB32A:  mul=4;
-                        break;
-                default: ADM_assert(0);
-        }
-        srd[0]=planes[0];
-        srd[1]=0;
-        srd[2]=0;
+		return 1;
+	}
 
-        ssrc[0]=mul*w;
-        if(strides)
-        {
-          if(strides[0]>ssrc[0]) ssrc[0]=strides[0]; 
-        }
-        ssrc[1]=0;
-        ssrc[2]=0;
+	// Else RGB colorspace
+	switch (_colorspace & 0x7FFF)
+	{
+		case ADM_COLOR_RGB16:
+		case ADM_COLOR_RGB555:
+		case ADM_COLOR_BGR555:
+			mul = 2;
+			break;
+		case ADM_COLOR_BGR24:
+		case ADM_COLOR_RGB24:
+			mul = 3;
+			break;
+		case ADM_COLOR_BGR32A:
+		case ADM_COLOR_RGB32A:
+			mul = 4;
+			break;
+		default:
+			ADM_assert(0);
+	}
 
-        dst[0]=target;
-        dst[1]=target+page;
-        dst[2]=target+((page*5)>>2);
-        ddst[0]=w;
-        ddst[1]=ddst[2]=w>>1;
-        if(_backward && (_colorspace==ADM_COLOR_BGR24 || _colorspace==ADM_COLOR_BGR32A || _colorspace==ADM_COLOR_RGB32A || 
-                    _colorspace==ADM_COLOR_RGB24))
-        {
-                ssrc[0]=-mul*w;
-                srd[0]=planes[0]+mul*w*(h-1);
-                dst[1]=target+page;
-                dst[2]=target+((page*5)>>2);
-        }
-        sws_scale((SwsContext *)_context,srd,ssrc,0,h,dst,ddst);
-     
-        return 1;
+	srd[0] = planes[0];
+	srd[1] = srd[2] = 0;
+	ssrc[0] = mul * w;
+	ssrc[1] = ssrc[2] = 0;
+
+	if(strides && strides[0] > ssrc[0])
+		ssrc[0] = strides[0];
+
+	dst[0] = target;
+	dst[2] = target + page;
+	dst[1] = target + ((page * 5) >> 2);
+	ddst[0] = w;
+	ddst[1] = ddst[2] = w >> 1;
+
+	if(_backward)
+	{
+		ssrc[0] = -mul * w;
+		srd[0] = planes[0] + mul * w * (h - 1);
+	}
+
+	sws_scale((SwsContext *)_context, srd, ssrc, 0, h, dst, ddst);
+
+	return 1;
 }
-//***************************************************
-//***************************************************
-//***************************************************
 //EOF
