@@ -20,7 +20,7 @@
  #define COLYUVRGB_H
 
 #define ADM_COLOR_IS_YUV 0x1000
- typedef enum ADM_colorspace
+ typedef enum 
  {
     ADM_COLOR_RGB24,
     ADM_COLOR_BGR24,
@@ -29,10 +29,12 @@
     ADM_COLOR_RGB16,
     ADM_COLOR_RGB555,
     ADM_COLOR_BGR555,
-    ADM_COLOR_YV12 = ADM_COLOR_IS_YUV,
+    ADM_COLOR_YV12 = ADM_COLOR_IS_YUV,	// YUV420
     ADM_COLOR_YUV422,
-    ADM_COLOR_YUV411
- };
+    ADM_COLOR_YUV422P,
+	ADM_COLOR_YUV411,
+	ADM_COLOR_YUV444
+ } ADM_colorspace;
 #define ADM_COLOR_BACKWARD 0x8000
 #define ADM_COLOR_MASK     0x7FFF
  /* Convert YV12 to RGB32, the reset must be called at least once before using scale */
@@ -53,12 +55,13 @@
  class ColYuvRgb : public ColBase
  {
   protected:
-    
+              uint32_t _inverted;
   public:
-                ColYuvRgb(uint32_t w, uint32_t h): ColBase(w,h) {};
+                ColYuvRgb(uint32_t w, uint32_t h,uint32_t inv=0): ColBase(w,h) {_inverted=inv;};
                 ~ColYuvRgb(){clean();};
       virtual  uint8_t reset(uint32_t neww, uint32_t newh);
-      virtual  uint8_t scale(uint8_t *src, uint8_t *target);  
+      virtual  uint8_t scale(uint8_t *src, uint8_t *target);
+      virtual  uint8_t scale(uint8_t *src, uint8_t *target,uint32_t startx,uint32_t starty, uint32_t w,uint32_t h,uint32_t totalW,uint32_t totalH);    
  };
  //********************************************
 
