@@ -29,14 +29,18 @@
 #include "ADM_inpics/ADM_pics.h"
 #include "ADM_nuv/ADM_nuv.h"
 #include "ADM_h263/ADM_h263.h"
-#include "ADM_3gp/ADM_3gp.h"
+//#include "ADM_3gp/ADM_3gp.h"
+#include "ADM_mp4/ADM_mp4.h"
 #include "ADM_avsproxy/ADM_avsproxy.h"
 #include "ADM_toolkit/toolkit.hxx"
 #include "ADM_editor/ADM_edit.hxx"
 #include "ADM_video/ADM_genvideo.hxx"
 #include "ADM_filter/video_filters.h"
+#include "ADM_mpegdemuxer/dmx_identify.h"
 #include "ADM_assert.h"
 
+DMX_TYPE dmxIdentify(const char *name);
+
 /**
 	Read the magic of a file i.e. its 16 first bytes
 */
@@ -85,17 +89,32 @@ uint8_t ADM_Composer::identify (char *name, fileType * type)
 	*type = VCodec_FileType;
 	return 1;	
     }
-    
+  // FLV
+    if (fourCC::check (id, (uint8_t *) "FLV\1"))
+    {
+	  printf (" \n FLV file detected...\n");
+	  *type =     FLV_FileType;
+	  return 1;
+    }
+
+
   // now try to identifies the filetype by its magic
   if (fourCC::check (id, (uint8_t *) "RIFF"))
     {
       printf (" \n Riff file detected...");
       if (fourCC::check (R32(magic[2]), (uint8_t *) "AVI "))
-	{
-	  printf (" \n AVI file detected...\n");
-	  *type = AVI_FileType;
-	  return 1;
-	}
+        {
+          printf (" \n AVI file detected...\n");
+          *type = AVI_FileType;
+          return 1;
+        }
+        if (fourCC::check (R32(magic[2]), (uint8_t *) "AMV "))
+        {
+          printf (" \n AMV file detected...\n");
+          *type = AMV_FileType;
+          return 1;
+        }
+
       printf (" \n Unknown Riff...");
       return 0;
     }
@@ -209,7 +228,7 @@ uint8_t ADM_Composer::identify (char *name, fileType * type)
                 *type=ECMAScript_FileType;
                 return 1;
         }
-        if(fourCC::check(id,(uint8_t *)"ADMX"))
+        if(fourCC::check(id,(uint8_t *)"ADMY") ||fourCC::check(id,(uint8_t *)"ADMX") )
         {
                 printf (" \n New mpeg index file detected..\n");
                 *type=NewMpeg_FileType;
@@ -232,14 +251,26 @@ uint8_t ADM_Composer::identify (char *name, fileType * type)
       		return 1;
 
     }
-    if(fourCC::check(R32(magic[2]),(uint8_t *)"matr") &&
-       fourCC::check(R32(magic[3]),(uint8_t *)"oska") )
+    if(magic[0]==R32(0xA3DF451A)) //x1a45DFA3 ))
     {
       printf (" \n Matroska file detected..\n");
       *type = Matroska_FileType;
       return 1;
 
     }    
+    /* Try harder to identify stuff */
+    switch(dmxIdentify(name))
+    {
+      case  DMX_MPG_ES :
+      case  DMX_MPG_H264_ES:
+      case  DMX_MPG_PS :
+      case  DMX_MPG_TS : 
+      case  DMX_MPG_TS2 : 
+                          printf("Probe says it is mpeg\n");
+                          *type = Mpeg_FileType;   return 1;
+      case  DMX_MPG_MSDVR  :*type = ASF_FileType; return 1;
+      
+    }
   printf ("\n unrecognized file detected...\n");
   fourCC::print(magic[0]); printf("\n");
   fourCC::print(magic[1]);
