@@ -26,7 +26,7 @@
 #include <pthread.h>
 #define WIN32_CLASH
 //#include <unistd.h>
-#ifdef CYG_MANGLING
+#ifdef ADM_WIN32
 #include "sys/stat.h"
 #endif
 #ifdef ADM_BSD_FAMILY
@@ -38,37 +38,39 @@
 #include "fourcc.h"
 #include "avio.hxx"
 #include "ADM_editor/ADM_edit.hxx"
-#include "ADM_script/ADM_JSGlobal.h"
 #include "ADM_inpics/ADM_pics.h"
 #include "ADM_nuv/ADM_nuv.h"
 #include "ADM_h263/ADM_h263.h"
-#include "ADM_3gp/ADM_3gp.h"
+//#include "ADM_3gp/ADM_3gp.h"
+#include "ADM_mp4/ADM_mp4.h"
 #include "ADM_openDML/ADM_openDML.h"
 #include "ADM_avsproxy/ADM_avsproxy.h"
 #include "ADM_toolkit/toolkit.hxx"
 #include "ADM_editor/ADM_edit.hxx"
 #include "ADM_video/ADM_genvideo.hxx"
 #include "ADM_filter/video_filters.h"
-#include "ADM_dialog/DIA_working.h"
+//#include "ADM_dialog/DIA_working.h"
 #include "ADM_ogm/ADM_ogm.h"
 #include "ADM_mpegdemuxer/dmx_video.h"
 #include "ADM_mpegdemuxer/dmx_identify.h"
 #include "ADM_mpegdemuxer/dmx_probe.h"
 #include "ADM_matroska/ADM_mkv.h"
+#include "ADM_flv/ADM_flv.h"
+#include "ADM_amv/ADM_amv.h"
 #include "ADM_asf/ADM_asf.h"
 #include "ADM_assert.h"
 #include "prefs.h"
 
-#include "ADM_toolkit/ADM_debugID.h"
+#include "ADM_osSupport/ADM_debugID.h"
 #define MODULE_NAME MODULE_EDITOR
-#include "ADM_toolkit/ADM_debug.h"
+#include "ADM_osSupport/ADM_debug.h"
 
 #ifdef USE_DIVX
 	#include "ADM_codecs/ADM_divx4.h"
 #endif
 #include "ADM_mpegdemuxer/dmx_indexer.h"
 #include "ADM_outputfmt.h"
-#include "ADM_gui2/GUI_ui.h"
+//#include "ADM_gui2/GUI_ui.h"
 int DIA_mpegIndexer (char **mpegFile, char **indexFile, int *aid,
 		     int already = 0);
 void DIA_indexerPrefill(char *name);
@@ -76,6 +78,7 @@ extern uint8_t indexMpeg (char *mpeg, char *file, uint8_t aid);
 
 extern uint8_t loadVideoCodecConf( char *name);
 extern uint8_t parseScript(char *name);
+uint8_t UI_SetCurrentFormat( ADM_OUT_FORMAT fmt );
 const char *VBR_MSG="Avidemux detected VBR MP3 audio in this file. For keeping audio/video in sync, time map is needed. Build it now?\n\nYou can do it later with \"Audio -> Build VBR Time Map\".";
 //
 //
@@ -94,7 +97,6 @@ uint32_t type,value;
   _audioSample=0;
   _lastseg = 99;
   _lastframe = 99;
-  _cached = 1;
   _nb_clipboard=0;
   _haveMarkers=0; // only edl have markers
   // Initialize a default postprocessing (dummy)
@@ -111,6 +113,8 @@ uint32_t type,value;
   _internalFlags=0;
   // Start with a clean base
   memset (_videos, 0, sizeof (_videos));
+  max_seg = MAX_SEG;
+  _segments = new _SEGMENT[max_seg];
   memset (_segments, 0, sizeof (_segments));
   _scratch=NULL;
   
@@ -224,18 +228,21 @@ ADM_Composer::deleteAllVideos (void)
 
 ADM_Composer::~ADM_Composer ()
 {
-  deleteAllSegments ();
-  deleteAllVideos ();
-  deletePostProc(&_pp);
-  if(_imageBuffer)
-  	delete _imageBuffer;
-  _imageBuffer=NULL;
-  if(_scratch)
-    {
-      delete _scratch;
-      _scratch=NULL;
-    }
+	deleteAllSegments();
+	deleteAllVideos();
+	deletePostProc(&_pp);
 
+	if(_segments)
+	{
+		delete[] _segments;
+		_segments=NULL;
+	}
+
+	if(_scratch)
+	{
+		delete _scratch;
+		_scratch=NULL;
+	}
 }
 
 /*
@@ -244,26 +251,36 @@ ADM_Composer::~ADM_Composer ()
 */
 
 /**
-	Load or append a file.
-	The file type is determined automatically and the ad-hoc video decoder is spawned
+    \fn addFile
+    \brief	Load or append a file.	The file type is determined automatically and the ad-hoc video decoder is spawned
+    
+    @param name: filename
+    @param mode: 0 open, 1 append
+    @param forcedType : if !=Unknown_FileType, it enables to force the file type
 
+    @return 1 on success, 0 on failure
+        
 
 */
-uint8_t ADM_Composer::addFile (char *name, uint8_t mode)
+uint8_t ADM_Composer::addFile (char *name, uint8_t mode,fileType forcedType)
 {
   uint8_t    ret =    0;
   aviInfo    info;
   WAVHeader *    _wavinfo;
 //  aviHeader *    tmp;
-  fileType    type =    Unknown_FileType;
+  fileType    type =    forcedType;
 
 UNUSED_ARG(mode);
 	_haveMarkers=0; // by default no markers are present
-  ADM_assert (_nb_segment < MAX_SEG);
+  ADM_assert (_nb_segment < max_seg);
   ADM_assert (_nb_video < MAX_VIDEO);
 
-  if (!identify (name, &type))
-    return 0;
+  // Autodetect file type ?
+  if(Unknown_FileType==type)
+  {
+      if (!identify (name, &type))
+        return 0;
+  }
 
 
 #define OPEN_AS(x,y) case x:\
@@ -284,7 +301,7 @@ UNUSED_ARG(mode);
               ret = _videos[_nb_video]._aviheader->open(name); 
               if(!ret)
               {
-                delete _videos[_nb_video]._aviheader;;
+                delete _videos[_nb_video]._aviheader;
                 printf("Trying mpeg\n"); 
                 goto thisIsMpeg; 
               }
@@ -315,15 +332,17 @@ UNUSED_ARG(mode);
 	}
       OPEN_AS (BMP_FileType, picHeader);
       OPEN_AS (Matroska_FileType, mkvHeader);
+      OPEN_AS (FLV_FileType, flvHeader);
       OPEN_AS (AvsProxy_FileType, avsHeader);
-      OPEN_AS (_3GPP_FileType, _3GPHeader);
-       OPEN_AS (Ogg_FileType, oggHeader);
+      OPEN_AS (_3GPP_FileType, MP4Header);
+      OPEN_AS (Ogg_FileType, oggHeader);
+      OPEN_AS (AMV_FileType, amvHeader);
 
     case Mpeg_FileType:
 thisIsMpeg:
     	// look if the idx exists
 	char tmpname[256];
-	ADM_assert(strlen(name)+5<256);;
+	ADM_assert(strlen(name)+5<256);
 	strcpy(tmpname,name);
 	strcat(tmpname,".idx");
         if(ADM_fileExist(tmpname))
@@ -340,7 +359,7 @@ thisIsMpeg:
                     printf("Filesystem is writable\n");
 		}else if( errno == EROFS ){
 		  char *tmpdir = getenv("TMPDIR");
-#ifdef CYG_MANGLING
+#ifdef ADM_WIN32
                         printf("Filesystem is not writable, looking for somewhere else\n");
 			if( !tmpdir )
 				tmpdir = "c:";
@@ -385,18 +404,18 @@ thisIsMpeg:
 	  printf ("\n not identified ...\n");
 	}
       else
-        GUI_Error_HIG(_("File type identified but no loader support detected..."),
-                      _("May be related to an old index file."));
+        GUI_Error_HIG(QT_TR_NOOP("File type identified but no loader support detected..."),
+                      QT_TR_NOOP("May be related to an old index file."));
       return 0;
     }
 
    // check opening was successful
    if (ret == 0) {
      char str[512+1];
-     snprintf(str,512,_("Attempt to open %s failed!"), name);
+     snprintf(str,512,QT_TR_NOOP("Attempt to open %s failed!"), name);
       str[512] = '\0';
       GUI_Error_HIG(str,NULL);
-      delete _videos[_nb_video]._aviheader;;
+      delete _videos[_nb_video]._aviheader;
       return 0;
    }
 
@@ -417,8 +436,8 @@ thisIsMpeg:
                  (strlen(str)?" and ":""),
                  (strlen(str)?" are ":" is ") );
          str[512] = '\0';
-         GUI_Error_HIG(str,_("You cannot mix different video dimensions yet. Using the partial video filter later, will not work around this problem. The workaround is:\n1.) \"resize\" / \"add border\" / \"crop\" each stream to the same resolution\n2.) concatinate them together"));
-         delete _videos[_nb_video]._aviheader;;
+         GUI_Error_HIG(str,QT_TR_NOOP("You cannot mix different video dimensions yet. Using the partial video filter later, will not work around this problem. The workaround is:\n1.) \"resize\" / \"add border\" / \"crop\" each stream to the same resolution\n2.) concatinate them together"));
+         delete _videos[_nb_video]._aviheader;
          return 0;
       }
    }
@@ -426,6 +445,19 @@ thisIsMpeg:
   // else update info
   _videos[_nb_video]._aviheader->getVideoInfo (&info);
   _videos[_nb_video]._aviheader->setMyName (name);
+  
+  // Printf some info about extradata
+  {
+    uint32_t l=0;
+    uint8_t *d=NULL;
+    _videos[_nb_video]._aviheader->getExtraHeaderData(&l,&d);
+    if(l && d)
+    {
+        printf("The video codec has some extradata (%d bytes)\n",l);
+        mixDump(d,l);
+        printf("\n");
+    }
+  }
   // 1st if it is our first video we update postproc
  if(!_nb_video)
  {
@@ -476,7 +508,7 @@ float duration;
 	duration*=1000;			// duration in seconds
 	duration*=_wavinfo->frequency;  	// In sample
 	_videos[_nb_video]._audio_duration=(uint64_t)floor(duration);
-       
+        printf("[Editor] Duration in seconds: %"LLU", in samples: %"LLU"\n",_videos[_nb_video]._audio_duration/_wavinfo->frequency,_videos[_nb_video]._audio_duration);
 
     }
 
@@ -493,7 +525,7 @@ float duration;
   uint8_t 	*d;
   _videos[_nb_video]._aviheader->getExtraHeaderData (&l, &d);
   _videos[_nb_video].decoder = getDecoder (info.fcc,
-					   info.width, info.height, l, d);
+					   info.width, info.height, l, d,info.bpp);
 
   _videos[_nb_video]._videoCache   =   new EditorCache(10,info.width,info.height) ;
   //
@@ -501,7 +533,7 @@ float duration;
   //
   _segments[_nb_segment]._reference = _nb_video;
   _segments[_nb_segment]._audio_size = _videos[_nb_video]._audio_size;
-  _segments[_nb_segment]._audio_duration =_videos[_nb_video]._audio_duration;;
+  _segments[_nb_segment]._audio_duration =_videos[_nb_video]._audio_duration;
   _segments[_nb_segment]._audio_start = 0;
   _segments[_nb_segment]._start_frame = 0;
   _segments[_nb_segment]._nb_frames   =   _videos[_nb_video]._nb_video_frames ;
@@ -514,7 +546,9 @@ float duration;
         if(_wavinfo)
         if(_wavinfo->encoding==WAV_MP3 && _wavinfo->blockalign==1152)
         {
-          if(GUI_Confirmation_HIG(_("Build Time Map"),_( "Build VBR time map?"), VBR_MSG))
+          uint32_t autovbr=0;
+          prefs->get(FEATURE_AUTO_BUILDMAP,&autovbr);
+          if(autovbr || GUI_Confirmation_HIG(QT_TR_NOOP("Build Time Map"),QT_TR_NOOP( "Build VBR time map?"), VBR_MSG))
                 {
                 _videos[_nb_video]._isAudioVbr=_videos[_nb_video]._audiostream->buildAudioTimeLine ();
                 }
@@ -548,7 +582,7 @@ TryAgain:
 		}
                 if(isH264Compatible(info.fcc))
                 {
-                  if(getEnv(ENV_EDITOR_X264) || GUI_Confirmation_HIG(_("Use that mode"),_("H264 detected"),_("If the file is using bframe as reference, it can lead to crash or stutteting.\nAvidemux can use another mode which is safed but <b>YOU WILL LOOSE FRAME ACCURACY</b>.\nDo you want to use that mode ?")))
+                  if(getEnv(ENV_EDITOR_X264) || GUI_Confirmation_HIG(QT_TR_NOOP("Use that mode"),QT_TR_NOOP("H264 detected"),QT_TR_NOOP("If the file is using bframe as reference, it can lead to crash or stutteting.\nAvidemux can use another mode which is safed but <b>YOU WILL LOOSE FRAME ACCURACY</b>.\nDo you want to use that mode ?")))
                     {
                               printf("Switching to non low delay codec\n");
                               _videos[_nb_video-1].decoder = getDecoderH264noLogic (info.fcc,  info.width, info.height, l, d);
@@ -561,7 +595,7 @@ TryAgain:
 		if( vid->_nb_video_frames >12) // 12
 		{
 				uint8_t 		*bufferin;
-				uint32_t 		len,flags,flag2;
+				uint32_t 		len,flags;
 				uint8_t 		bframe=0, bconsistency=1;
 				uint32_t		scanned=12;
                                 ADMImage                *buffer=NULL;
@@ -575,14 +609,14 @@ TryAgain:
                                 else
 				        buffer=new ADMImage(info.width,info.height);
 				// we decode 5 frames..should be enough to get an opinion
+                                ADMCompressedImage img;
+                                img.data=bufferin;
 				for(uint32_t i=0;i<scanned;i++)  //10
 				{
-					flags=flag2=0;
-  					vid->_aviheader->getFrameNoAlloc (i,
-							 bufferin,
-							 &len, &flags);
-                                        if(!len) continue;
-					if(!vid->decoder->uncompress( (uint8_t *)bufferin,buffer,len,&flag2 ))
+					flags=0;
+  					vid->_aviheader->getFrameNoAlloc (i,&img);
+                                        if(!img.dataLength) continue;
+					if(!vid->decoder->uncompress( &img,buffer ))
 					{
 						err++;
 						printf("\n ***oops***\n");
@@ -592,7 +626,7 @@ TryAgain:
 					
 					// check if it is a b-frame
 					//printf(" %lu : %lu \n",i,flag2);
-					if(flag2 & AVI_B_FRAME)
+					if(buffer->flags & AVI_B_FRAME)
 					{
 						printf(" * ");
 					 	bframe=1;
@@ -617,10 +651,15 @@ TryAgain:
 					bconsistency=0;
 					
 				}
-				if(bframe)
+                                uint32_t ffcheck=vid->decoder->isDivxPacked ();
+                                if(ffcheck)
+                                {
+                                  printf("[Editor] Decoder says it is vop packed\n");
+                                }
+				if(bframe || ffcheck)
 				{
 					printf("\n Mmm this appear to have b-frame...\n");
-					if(bconsistency)
+					if(bconsistency )
 					{
 						printf("\n And the index is ok\n");
 
@@ -647,23 +686,31 @@ TryAgain:
 					{
 						printf("\n But the  index is not up to date \n");
 						uint32_t ispacked=0;
+                                                
+                                                uint32_t ff=vid->decoder->isDivxPacked ();
+                                                if(ff)
+                                                {
+                                                  printf("[Editor] Decoder says it is vop packed\n");
+                                                }
+                                                
 						// If it is Divx 5.0.xxx use divx decoder
-						if(fourCC::check(info.fcc,(uint8_t *)"DX50")
-						|| fourCC::check(info.fcc,(uint8_t *)"XVID" ))
+						if(isMpeg4Compatible(info.fcc))
 						{
 
 
 							//if(vid->decoder->isDivxPacked())
 							uint8_t forced= getEnv(ENV_EDITOR_PVOP);
-							if(vid->decoder->isDivxPacked() ||forced)
+							if(ff ||forced)
 							{
 								
 								// can only unpack avi
 								if(!count && type==AVI_FileType)
 								{
-									if( forced || GUI_YesNo(
-                                                                                _("Packed Bitstream detected"),
-                                                                        _("Do you want me to unpack it ?")))
+                                                                  uint32_t autounpack=0;
+                                                                  prefs->get(FEATURE_AUTO_UNPACK,&autounpack);
+									if( forced || autounpack || GUI_YesNo(
+                                                                                QT_TR_NOOP("Packed Bitstream detected"),
+                                                                        QT_TR_NOOP("Do you want me to unpack it ?")))
 									{
 									OpenDMLHeader *dml=NULL;
 									count++;	
@@ -683,18 +730,18 @@ TryAgain:
                                            info.width, info.height, l, d);
 										goto TryAgain;
 									}
-                                                                        GUI_Error_HIG(_("Could not unpack the video"),_( "Using backup decoder - not frame accurate."));
+                                                                        GUI_Error_HIG(QT_TR_NOOP("Could not unpack the video"),QT_TR_NOOP( "Using backup decoder - not frame accurate."));
 									}
 								}
 #if  1 //def USE_DIVX
                                                                 if(count)
-                                                                        GUI_Info_HIG(ADM_LOG_IMPORTANT,_("Weird"),_( "The unpacking succeedeed but the index is still not up to date."));
+                                                                        GUI_Info_HIG(ADM_LOG_IMPORTANT,QT_TR_NOOP("Weird"),QT_TR_NOOP( "The unpacking succeedeed but the index is still not up to date."));
 								printf("\n Switching codec...\n");
 								delete vid->decoder;
 								vid->decoder=getDecoderVopPacked(info.fcc, info.width,info.height,0,NULL);
 								ispacked=1;
 #else
-								GUI_Info_HIG(ADM_LOG_IMPORTANT,_("Troubles ahead"), _("This a VOP packed AVI."));
+								GUI_Info_HIG(ADM_LOG_IMPORTANT,QT_TR_NOOP("Troubles ahead"), QT_TR_NOOP("This a VOP packed AVI."));
 #endif
 
 							}
@@ -703,7 +750,9 @@ TryAgain:
 						// else warn user
 						if(!ispacked)
                                                 {
-                                                  if(GUI_YesNo(_("Index is not up to date"),_("You should use Tool->Rebuild frame. Do it now ?")))
+                                                   uint32_t reindex=0;
+                                                  prefs->get(FEATURE_AUTO_REBUILDINDEX,&reindex);
+                                                  if(reindex || GUI_YesNo(QT_TR_NOOP("Index is not up to date"),QT_TR_NOOP("You should use Tool->Rebuild frame. Do it now ?")))
                                                         {
                                                                 rebuildFrameType();
 							}
@@ -816,6 +865,13 @@ uint8_t ADM_Composer::cleanup (void)
   _nb_segment = 0;
   _nb_video = 0;
   _total_frames = 0;
+
+	if(_scratch)
+	{
+		delete _scratch;
+		_scratch=NULL;
+	}
+
   return 1;
 }
 /*
@@ -827,10 +883,15 @@ uint8_t ADM_Composer::cleanup (void)
 uint8_t ADM_Composer::addSegment(uint32_t source,uint32_t start, uint32_t nb)
 {
         // do some sanity check
-        if(_nb_segment==MAX_SEG-1)
-        {
-                printf("[editor] Too many segments %d\n",_nb_segment);
-                return 0;
+        if(_nb_segment==max_seg-1)
+	{
+	   _SEGMENT *s;
+            max_seg += MAX_SEG;
+            s = new _SEGMENT[max_seg];
+            memset (s, 0, sizeof(_SEGMENT)*max_seg);
+            memcpy(s,_segments,sizeof(_SEGMENT)*(max_seg-MAX_SEG));
+            delete _segments;
+            _segments = s;
         }
         if(_nb_video<=source)
         {
@@ -1446,7 +1507,6 @@ uint8_t r=0;
 //    Try indexing the file, return 1 if file successfully indexed 
 //              0 else
 //_________________________________________
-extern uint8_t DIA_dmx(char *file,DMX_TYPE format,uint32_t nbTracks, MPEG_TRACK *tracks, uint32_t *selectedTracks);
 //
 uint8_t         ADM_Composer::tryIndexing(char *name,char *idxname)
 {
@@ -1454,7 +1514,7 @@ uint8_t         ADM_Composer::tryIndexing(char *name,char *idxname)
       prefs->get(FEATURE_TRYAUTOIDX,&autoidx);
       if (!autoidx)
         {
-          if (!GUI_Question (_("This looks like mpeg\n Do you want to index it?")))
+          if (!GUI_Question (QT_TR_NOOP("This looks like mpeg\n Do you want to index it?")))
             {
                 return 0;
             }
@@ -1472,7 +1532,7 @@ uint8_t         ADM_Composer::tryIndexing(char *name,char *idxname)
                 }
 
           
-                if(type==DMX_MPG_PS || type==DMX_MPG_TS)
+                if(type==DMX_MPG_PS || type==DMX_MPG_TS || type==DMX_MPG_TS2)
                 {
                        if(nbTrack>2)
 		       if(autoidx)
@@ -1506,7 +1566,7 @@ uint8_t         ADM_Composer::tryIndexing(char *name,char *idxname)
                         delete [] tracks;
                 delete [] idx;
 
-                if(!r) GUI_Error_HIG(_("Indexing failed"), NULL); 
+                if(!r) GUI_Error_HIG(QT_TR_NOOP("Indexing failed"), NULL); 
                 return r;
 }
 /**
