@@ -24,7 +24,7 @@
 
 #include "ADM_assert.h"
 #include "fourcc.h"
-#include "ADM_toolkit/ADM_quota.h"
+#include "ADM_osSupport/ADM_quota.h"
 #include "ADM_editor/ADM_edit.hxx"
 #include "ADM_toolkit/toolkit.hxx"
 
@@ -32,16 +32,14 @@
 #include "ADM_vidEncode.hxx"
 #include "ADM_video/ADM_genvideo.hxx"
 
-#include "ADM_toolkit/ADM_debugID.h"
+#include "ADM_osSupport/ADM_debugID.h"
 #define MODULE_NAME MODULE_ENCODER
-#include "ADM_toolkit/ADM_debug.h"
-
-#include "ADM_dialog/DIA_enter.h"
-#include "ADM_gui2/GUI_ui.h"
+#include "ADM_osSupport/ADM_debug.h"
 
 
+void UI_setVideoCodec( int i);
 // Some static stuff
-static COMPRES_PARAMS *videoCodecGetDescriptor (SelectCodecType codec);
+COMPRES_PARAMS *videoCodecGetDescriptor (SelectCodecType codec);
 void setVideoEncoderSettings (COMPRESSION_MODE mode, uint32_t param,     uint32_t extraConf, uint8_t * extraData);
 static void encoderPrint (void);
 static const char *encoderGetName (void);
@@ -86,7 +84,7 @@ const char *encoderGetIndexedName (uint32_t i);
 
 #include "ADM_encCodecDesc.h"
 
-SelectCodecType current_codec = CodecFF;
+SelectCodecType current_codec = CodecCopy;
 ///////////////////////////////////////////
 
 
@@ -143,6 +141,7 @@ videoCodecGetDescriptor (SelectCodecType codec)
   printf ("Warning ! codec %d not found\n", codec);
   return NULL;
 }
+
 uint8_t
 videoCodecSetFinalSize (uint32_t size)
 {
@@ -190,13 +189,13 @@ EncoderSaveMpeg (const char *name)
       raw = 2;
       break;
     default:
-      GUI_Error_HIG (_("Wrong output format"), _("Select MPEG as the output."));
+      GUI_Error_HIG (QT_TR_NOOP("Wrong output format"), QT_TR_NOOP("Select MPEG as the output."));
       return 0;
     }
   if (current_codec != CodecDVD && raw == 2)
     {
-      GUI_Error_HIG (_("Wrong video codec"),
-                     _("Select DVD as the video codec for MPEG TS output."));
+      GUI_Error_HIG (QT_TR_NOOP("Wrong video codec"),
+                     QT_TR_NOOP("Select DVD as the video codec for MPEG TS output."));
       return 0;
     }
   switch (current_codec)
@@ -267,7 +266,7 @@ videoCodecConfigureAVI (char *cmdString, uint32_t optSize, uint8_t * opt)
 	}
       if (equal == 0xfff)
 	{
-	  printf ("\n I did not understand the args for video conf.\n");
+	  printf ("\n I did not understood the args for video conf.\n");
 	  return 0;
 	}
       go = cs + equal + 1;
@@ -463,6 +462,7 @@ saveEncoderConfig (void)
     }
 
 }
+    
 const char *
 encoderGetName (void)
 {
@@ -697,9 +697,15 @@ getVideoEncoder (uint32_t w, uint32_t h, uint32_t globalHeaderFlag)
     case CodecHuff:
       e = new EncoderFFMPEGHuff (&ffmpegHUFF);
       break;
+    case CodecFLV1:
+       e = new EncoderFFMPEGFLV1 (&ffmpegFLV1);
+       break;
     case CodecFFV1:
       e = new EncoderFFMPEGFFV1 (&ffmpegFFV1);
       break;
+    case CodecDV:
+        e = new EncoderFFMPEGDV (&ffmpegDV);
+      break;
     case CodecSnow:
       e = new EncodeFFMPEGSNow (&ffmpegSnow);
       break;
@@ -709,7 +715,7 @@ getVideoEncoder (uint32_t w, uint32_t h, uint32_t globalHeaderFlag)
     case CodecH263:
       if (!((w == 128) && (h == 96)) && !((w == 176) && (h == 144)))
 	{
-          GUI_Error_HIG (_("Only QCIF and subQCIF are allowed for H.263"), NULL);
+          GUI_Error_HIG (QT_TR_NOOP("Only QCIF and subQCIF are allowed for H.263"), NULL);
 	  return 0;
 	}
       e = new EncoderFFMPEG (FF_H263, &ffmpegH263Codec);
@@ -849,6 +855,19 @@ uint8_t mk_hex (uint8_t a, uint8_t b)
   return (a1 << 4) + b1;
 
 }
+/**
+
+*/
+/**
+    \fn videoCodecGetDescriptorByIndex (int index)
+    \brief Returns codec descriptor by its index (ugly)
+*/
+COMPRES_PARAMS *videoCodecGetDescriptorByIndex (int index)
+{
+  ADM_assert(index<encoderGetNbEncoder());
+  COMPRES_PARAMS *param=AllVideoCodec[index];
+  return param;
+}
 // Old stuff
 uint8_t
 videoCodecGetConf (uint32_t * optSize, uint8_t ** data)
@@ -888,7 +907,7 @@ videoCodecSetConf (char *name, uint32_t extraLen, uint8_t * extraData)
   param = videoCodecGetDescriptor (current_codec);
   if (!param)
     {
-      GUI_Error_HIG (_("Fatal error"), NULL);
+      GUI_Error_HIG (QT_TR_NOOP("Fatal error"), NULL);
       printf ("Current codec:%d\n", current_codec);
       ADM_assert (0);
     }
@@ -904,7 +923,7 @@ videoCodecSetConf (char *name, uint32_t extraLen, uint8_t * extraData)
     }
 
 }
-
+/*
 uint8_t oplug_mpegInit(void)
 {
 		// Init from prefs
@@ -935,7 +954,32 @@ uint8_t oplug_mpegInit(void)
   prefs->get( CODECS_DVD_MAXBITRATE, &DVDExtra.maxBitrate);
   DVDExtra.maxBitrate = (DVDExtra.maxBitrate*1000) >> 3;
   return 1;
+} */
+
+#ifdef USE_XVID_4
+/**
+    \fn     setIpod_Xvid4Preset(void)
+    \brief  set XVID4 codec conf to the Ipod preset
+*/
+void setIpod_Xvid4Preset(void)
+{
+ memcpy(&xvid4Extra,&xvid4ExtraIPOD,sizeof(xvid4ExtraIPOD)); 
 }
+#endif
+
+#ifdef USE_X264
+/**
+    \fn     setPSP_X264Preset(void)
+    \brief  set x264 codec conf to the PSP preset
+*/
+void setPSP_X264Preset(void)
+{
+  
+ memcpy(&x264Extra,&x264ExtraPSP,sizeof(x264ExtraPSP)); 
+ printf("Cabac :%u\n",x264Extra.CABAC);
+}
+#endif
+/*
 uint8_t oplug_mpegStore(void)
 {
   uint32_t br;
@@ -971,6 +1015,6 @@ uint8_t oplug_mpegStore(void)
   br=(DVDExtra.maxBitrate<< 3)/1000;;
   prefs->set( CODECS_DVD_MAXBITRATE,  br);
   return 1;
-}
+} */
 
 // EOF
