@@ -26,7 +26,7 @@
 
 
 
-#ifdef USE_FFMPEG
+
 #include "ADM_lavcodec.h"
 
 
@@ -91,7 +91,7 @@ EncoderFFMPEGHuff::configure (AVDMGenericVideoStream * instream)
   ADM_assert (_vbuffer);
   _in = instream;
 
-  _codec = new ffmpegEncoderCQ (_w, _h, _id);
+  _codec = new ffmpegEncoderHuff(_w, _h, _id);
   _codec->init (_param.qz, _fps, 0);
   return 1;
 
@@ -222,6 +222,97 @@ EncodeFFMPEGSNow::configure (AVDMGenericVideoStream * instream)
 
 }
 
+//*********************DV **********************************************
+EncoderFFMPEGDV::EncoderFFMPEGDV (COMPRES_PARAMS * config):
+EncoderFFMPEG (FF_DV, config)
+{
+  _id = FF_DV;
+  _frametogo = 0;
+
+
+}
+uint8_t
+EncoderFFMPEGDV::hasExtraHeaderData (uint32_t * l, uint8_t ** data)
+{
+  *l = 0;
+  *data = NULL;
+  return 0;
+
+}
+uint8_t
+EncoderFFMPEGDV::configure (AVDMGenericVideoStream * instream)
+{
+  ADM_assert (instream);
+  ADV_Info *info;
+
+
+
+  info = instream->getInfo ();
+  _fps = info->fps1000;
+  _w = info->width;
+  _h = info->height;
+  
+  _vbuffer = new ADMImage (_w, _h);
+  ADM_assert (_vbuffer);
+  _in = instream;
+
+  if(_w!=720 || _h!=576 || _fps!=25000)
+  {
+    GUI_Error_HIG(QT_TR_NOOP("Incompatible settings"),QT_TR_NOOP("At the moment, the DV codec only accepts 720*576@25"));
+    return 0;
+  }
+  _codec = new ffmpegEncoderCQ (_w, _h, _id);
+  _codec->init (_param.qz, _fps, 0);
+  _state=enc_CQ;
+  return 1;
+
+
+
+}
+//********************* FLV1 **********************************************
+EncoderFFMPEGFLV1::EncoderFFMPEGFLV1 (COMPRES_PARAMS * config):
+EncoderFFMPEG (FF_FLV1, config)
+{
+  _id = FF_FLV1;
+  _frametogo = 0;
+
+
+}
+uint8_t
+EncoderFFMPEGFLV1::hasExtraHeaderData (uint32_t * l, uint8_t ** data)
+{
+  *l = 0;
+  *data = NULL;
+  return 0;
+
+}
+uint8_t
+EncoderFFMPEGFLV1::configure (AVDMGenericVideoStream * instream)
+{
+  ADM_assert (instream);
+  ADV_Info *info;
+
+
+
+  info = instream->getInfo ();
+  _fps = info->fps1000;
+  _w = info->width;
+  _h = info->height;
+  
+  _vbuffer = new ADMImage (_w, _h);
+  ADM_assert (_vbuffer);
+  _in = instream;
+
+ 
+  _codec = new ffmpegEncoderCBR (_w, _h, _id);
+  _codec->setConfig (&_settings);
+  _codec->init (_param.bitrate, _fps, 0);
+  _state=enc_CQ;
+  return 1;
+
+
+
+}
 
 //************************* SNOW **************************
 // return codec name as seen in avi header
@@ -231,6 +322,9 @@ EncoderFFMPEG::getCodecName (void)
 {
   switch (_id)
     {
+    case FF_DV:
+        return "dvsd";
+        break;
     case FF_FFHUFF:
       return "FFVH";
       break;
@@ -250,6 +344,9 @@ EncoderFFMPEG::getCodecName (void)
     case FF_SNOW:
       return "SNOW";
       break;
+    case FF_FLV1:
+      return "FLV1";
+      break;
 
     default:
       ADM_assert (0);
@@ -482,4 +579,4 @@ uint8_t EncoderFFMPEG::startPass2 (void)
 }
 //-----------------------ffmpegEncoderHuff
 
-#endif
+
