@@ -24,8 +24,8 @@
  ***************************************************************************/
 #ifndef __ADM_encoder__
 #define __ADM_encoder__
-#include "ADM_library/ADM_image.h"
-#include "ADM_library/ADM_bitstream.h"
+#include "ADM_image.h"
+#include "ADM_bitstream.h"
 typedef enum
 {
 
@@ -95,6 +95,7 @@ public:
   virtual const char *getCodecName (void) = 0;
   virtual const char *getFCCHandler (void) = 0;
   virtual const char *getDisplayName (void) = 0;
+  virtual uint8_t verifyLog(const char *,uint32_t nb) { return 1;} // Verify 1st pass log file..
 
 
 };
