@@ -18,8 +18,9 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <ADM_assert.h>
-#include <ADM_assert.h>
+#include <vector>
+
+#include "ADM_assert.h"
 #include "config.h"
 #include "fourcc.h"
 #include "avio.hxx"
@@ -27,20 +28,19 @@
 #include "ADM_toolkit/toolkit.hxx"
 #include "ADM_editor/ADM_edit.hxx"
 #include "ADM_video/ADM_genvideo.hxx"
+#include "ADM_video/ADM_videoNull.h"
 #include "ADM_filter/video_filters.h"
 #include "ADM_video/ADM_vidPartial.h"
-#include "avi_vars.h"
+#include "ADM_userInterfaces/ADM_commonUI/GUI_render.h"
 
-#include "ADM_toolkit/ADM_debugID.h"
+#include "ADM_osSupport/ADM_debugID.h"
 #define MODULE_NAME MODULE_PREVIEW
-#include "ADM_toolkit/ADM_debug.h"
-#include "ADM_toolkit/ADM_quota.h"
+#include "ADM_osSupport/ADM_debug.h"
+#include "ADM_osSupport/ADM_quota.h"
 //
-void updateVideoFilters( void );
 // exported vars
-uint32_t nb_video_filter=0;
+std::vector <FILTER_ENTRY> allfilters;
 uint32_t nb_active_filter=0;
-FILTER_ENTRY allfilters[MAX_FILTER];
 FILTER  videofilters[MAX_FILTER];
 
 static uint32_t lastStart=0, lastNb=0;
@@ -49,10 +49,12 @@ extern ADM_Composer *video_body;
 extern AVDMGenericVideoStream *filterCreateFromTag(VF_FILTERS tag,CONFcouple *conf, AVDMGenericVideoStream *in) ;
 extern char *ADM_escape(const ADM_filename *incoming);
 //
-static   AVDMGenericVideoStream *preview=NULL;
+
+static  void updateVideoFilters(void);
+
 // Ugly should be dynamically allocated
 #warning HARDCODEC IMAGE SIZE
-static ADMImage *unpackd;
+
 // dummy constructor used to register the filter
 //____________________________________
 AVDMVideo_FilterDec::AVDMVideo_FilterDec(char *name,
@@ -75,13 +77,12 @@ void filterCleanUp( void )
              videofilters[i].filter=NULL;  		
 	}
    nb_active_filter=0;
-   preview=NULL;
 }
 void filterListAll( void )
 {
 char *name;
-	printf("\n Video filters\n");
-	for(uint32_t i=0;i<nb_video_filter;i++)
+	printf("\nVideo filters\n");
+	for(uint32_t i=0;i<allfilters.size();i++)
 	{
 		name=allfilters[ i].filtername;
 		if(allfilters[ i].viewable)
@@ -96,10 +97,10 @@ VF_FILTERS filterGetTagFromName(char *inname)
 {
 char *name;
 	VF_FILTERS filter=VF_DUMMY;
-	for(uint32_t i=0;i<nb_video_filter;i++)
+	for(uint32_t i=0;i<allfilters.size();i++)
 	{
 		name=allfilters[ i].filtername;
-		if(allfilters[ i].viewable)
+		if(allfilters[ i].viewable || allfilters[i].tag==VF_PARTIAL)
 		{
 			if(name)
 			{
@@ -117,36 +118,25 @@ void registerFilter(const char *name,VF_FILTERS tag,uint8_t viewable
 		,AVDMGenericVideoStream *(*create) (AVDMGenericVideoStream *in, CONFcouple *)
 		,char *filtername)
 {
-        ADM_assert(nb_video_filter<(MAX_FILTER-1));
-        allfilters[ nb_video_filter].name=name;
-        allfilters[ nb_video_filter].create=create;
-        allfilters[ nb_video_filter].tag=tag;
-        allfilters[ nb_video_filter].viewable=viewable;
-	allfilters[ nb_video_filter].filtername=filtername;
-        nb_video_filter ++;
+//        printf ("*nb_video_filter() = %d, max %d, name = %s\n", nb_video_filter(), (MAX_FILTER-1), name);
+        allfilters.push_back (FILTER_ENTRY (name, create, tag, viewable, filtername));
 
         if(viewable==1)
 	{
-        	aprintf("\n Registred filter %lu: %s",nb_video_filter,name);
+        	aprintf("\nRegistered filter %lu: %s",allfilters.size(),name);
 	}
 }
 void registerFilterEx(const char *name,VF_FILTERS tag,uint8_t viewable
 		,AVDMGenericVideoStream *(*create) (AVDMGenericVideoStream *in, CONFcouple *)
 		,char *filtername,AVDMGenericVideoStream *(*create_from_script) (AVDMGenericVideoStream *in, int n,Arg *args),char *desc)
 {
-        ADM_assert(nb_video_filter<(MAX_FILTER-1));
-        allfilters[ nb_video_filter].name=name;
-        allfilters[ nb_video_filter].create=create;
-        allfilters[ nb_video_filter].tag=tag;
-        allfilters[ nb_video_filter].viewable=viewable;
-	allfilters[ nb_video_filter].filtername=filtername;
-	allfilters[ nb_video_filter].create_from_script=create_from_script;
-        allfilters[ nb_video_filter].description=desc;
-        nb_video_filter ++;
+//    printf ("nb_video_filter = %d, max %d, name = %s\n", nb_video_filter, (MAX_FILTER-1), name);
+        allfilters.push_back (FILTER_ENTRY (name, create, tag, viewable,
+                                            filtername, desc, create_from_script));
 
         if(viewable==1)
 	{
-        	aprintf("\n Registred filter %lu: %s",nb_video_filter,name);
+        	aprintf("\nRegistered filter %lu: %s",allfilters.size(),name);
 	}
 
 
@@ -156,8 +146,7 @@ The reference is 0 in that case !
 ************************************************************************************************/
 AVDMGenericVideoStream *getLastVideoFilter(void)
 {
-extern ADM_Composer *video_body;
-aviInfo info;
+    aviInfo info;
 
 	video_body->getVideoInfo(&info);
 
@@ -168,7 +157,6 @@ aviInfo info;
   	if(nb_active_filter==0)
   		{
   		 		nb_active_filter=1;
-  		 		preview=videofilters[0].filter=  new AVDMVideoStreamNull(video_body,0,info.nb_frames);
 				aprintf("--preview filter 0\n");
 				return videofilters[  nb_active_filter-1].filter;
   		}
@@ -182,7 +170,6 @@ aviInfo info;
 */
 AVDMGenericVideoStream *getLastVideoFilter( uint32_t start, uint32_t nb)
 {
-extern ADM_Composer *video_body;
   // sanity check
   	lastNb=nb;
 	lastStart=start;
@@ -199,7 +186,6 @@ extern ADM_Composer *video_body;
 /********* Returns the first video filters starting from frame xx with nb frames ***************/
 AVDMGenericVideoStream *getFirstVideoFilter( uint32_t start, uint32_t nbFrame)
 {
-extern ADM_Composer *video_body;
   // sanity check
   	lastNb=nbFrame;
 	lastStart=start;
@@ -214,7 +200,6 @@ AVDMGenericVideoStream *getFirstCurrentVideoFilter( void)
 }
 AVDMGenericVideoStream *getFirstVideoFilter( void)
 {
-extern ADM_Composer *video_body;
   // sanity check
   aviInfo info;
 
@@ -227,6 +212,13 @@ extern ADM_Composer *video_body;
 
 }
 
+FILTER * getCurrentVideoFilterList (uint32_t * count)
+{
+    if (count)
+        *count = nb_active_filter;
+    return videofilters;
+}
+
 //
 //	Parse the list of active filters, delete them et recreate them with (new ?) configuration
 //
@@ -243,26 +235,26 @@ void updateVideoFilters(void )
   		if(nb_active_filter<=1)
   		{
   		 	nb_active_filter=1;
-			preview=videofilters[0].filter;
 			aprintf("--preview filter %d\n",nb_active_filter-1);
+                        admPreview::updateFilters(videofilters[0].filter,videofilters[nb_active_filter-1].filter);
   		 	return;
   		}
   		// Rebuild other filters
-  		    for(uint32_t i=1;i<nb_active_filter;i++)
-						{
-                   		VF_FILTERS tag;
-                    		AVDMGenericVideoStream *old;
-                   			old= videofilters[i].filter;
-                  			tag=videofilters[i].tag;
-
-                      	videofilters[i].filter=filterCreateFromTag(tag,
-                            			videofilters[i].conf,
-                               			videofilters[i-1].filter);
-
+                for(uint32_t i=1;i<nb_active_filter;i++)
+                {
+                    VF_FILTERS tag;
+                    AVDMGenericVideoStream *old;
+                            old= videofilters[i].filter;
+                            tag=videofilters[i].tag;
+  
+                            videofilters[i].filter=filterCreateFromTag(tag,
+                                                videofilters[i].conf,
+                                                videofilters[i-1].filter);
                           delete old;
-            	}
-		preview=videofilters[nb_active_filter-1].filter;
+                }
 		aprintf("--preview filter %d\n",nb_active_filter-1);
+                ADM_assert(nb_active_filter);
+                admPreview::updateFilters(videofilters[0].filter,videofilters[nb_active_filter-1].filter);
 }
 //
 //	Create a filter from : its tag, its config and an input stream
@@ -273,14 +265,29 @@ AVDMGenericVideoStream *filterCreateFromTag(VF_FILTERS tag,CONFcouple *couple, A
 	 AVDMGenericVideoStream *filter;
 
 			ADM_assert(tag!=VF_INVALID);
-			for(unsigned int i=0;i<nb_video_filter;i++)
-				{
-					if(tag==allfilters[i].tag)
-						{
-	 						filter=allfilters[i].create( in, couple);
-							return filter;
-						}
-				}
+                        if(tag>=VF_EXTERNAL_START)
+                        {
+                          // start from the end, it is an external filter 
+                          for(uint32_t i=allfilters.size()-1;i>=0;i--)
+                          {
+                              if(tag==allfilters[i].tag)
+                                {
+                                        filter=allfilters[i].create( in, couple);
+                                        return filter;
+                                }
+                          }
+                        } // else search forward
+                        else
+                        {
+                          for(unsigned int i=0;i<allfilters.size();i++)
+                                  {
+                                          if(tag==allfilters[i].tag)
+                                                  {
+                                                          filter=allfilters[i].create( in, couple);
+                                                          return filter;
+                                                  }
+                                  }
+                        }
 			ADM_assert(0);
 			return NULL;                      
 }
@@ -288,20 +295,25 @@ AVDMGenericVideoStream *filterCreateFromTag(VF_FILTERS tag,CONFcouple *couple, A
 
 
 */
+const FILTER_ENTRY * filterGetEntryFromTag (VF_FILTERS tag)
+{
+    ADM_assert(tag!=VF_INVALID);
+    for(unsigned int i=0;i<allfilters.size();i++)
+    {
+        if(tag==allfilters[i].tag)
+        {
+            return &(allfilters[i]);
+        }
+    }
+    ADM_assert(0);
+    return NULL;                      
+}
+
 const char  *filterGetNameFromTag(VF_FILTERS tag)
 {
-
-                        ADM_assert(tag!=VF_INVALID);
-                        for(unsigned int i=0;i<nb_video_filter;i++)
-                                {
-                                        if(tag==allfilters[i].tag)
-                                                {
-                                                        return allfilters[i].name;
-                                                        
-                                                }
-                                }
-                        ADM_assert(0);
-                        return NULL;                      
+    const FILTER_ENTRY * entry = filterGetEntryFromTag (tag);
+    ADM_assert(entry);
+    return entry->name;
 }
 /*____________________________________
 	Save and load current set of filters
@@ -314,61 +326,7 @@ const char  *filterGetNameFromTag(VF_FILTERS tag)
 
 /*---------------------------------------*/	 
 
-/* if refresh=1 we use the current full filter list
-	else we rebuild a new one */
-void 	editorReignitPreview( void )
-{
-		aprintf("--killing\n");
-            GUI_PreviewEnd();
 
-	    	getFirstVideoFilter();
-	   
-	    preview=videofilters[  nb_active_filter-1].filter;
-	    aprintf("--spawning\n");
-	    if(unpackd)
-	    {
-	    	delete unpackd;
-		unpackd=NULL;		
-	    }
-	    unpackd=new ADMImage(preview->getInfo()->width,preview->getInfo()->height);
-            GUI_PreviewInit(preview->getInfo()->width,preview->getInfo()->height,0);
-}
-
-
-void editorKillPreview( void )
-{
-      GUI_PreviewEnd();
-      if(unpackd)
-      	delete unpackd;
-      unpackd=NULL;
-}
-
-
-
-
-void editorUpdatePreview(uint32_t framenum)
-{
-//
-//
-//
-	uint32_t fl,len;	
- 	ADM_assert(preview);
-	ADM_assert(unpackd);
-
-  if( GUI_StillAlive())
-  {
-  		aprintf("Preview: Ask for frame %lu\n",framenum);
-		if(framenum<=preview->getInfo()->nb_frames-1)
-		{
-			preview->getFrameNumberNoAlloc(framenum,&len,unpackd,&fl);
-			GUI_PreviewUpdate(unpackd->data);
-		}
-  }
-
-//   virtual uint8_t getFrameNumberNoAlloc(uint32_t frame, uint32_t *len,
-//          																				uint8_t *data,uint32_t *flags)=0;
-
-}
 //______________________________________________________
 // Check and build a confCouple from the args
 // the filter_param arg is a template for that filter
@@ -377,61 +335,112 @@ CONFcouple *filterBuildCouple(FILTER_PARAM *param,uint32_t nb,Arg *args)
 {
 int found,l;
 int trans[MAXPARAM];
-	if(nb!=param->nb)
+	if(param->nb>VARIABLE_PARAMS)
 	{
-		printf("# of parameters mismatch\n");
-		return NULL;
-	}
-	// For each param check we are ok
-	// the generic form is name=value
-	// name should be the same as in the param array
-	for(int i=0;i<nb;i++)
-	{
-		l=strlen(param->param[i]);
-		ADM_assert(l);
-		found=-1;
-		for(int j=0;j<nb;j++)
-		{
-			if(!strncasecmp(param->param[i],args[j].arg.string,l))
-			{
-				if(strlen(args[j].arg.string)>l+1 && args[j].arg.string[l]=='=')
+		// Variable # of parameters
+		// We check we have at least what is required by the template
+		for(int i=0;i<(param->nb-VARIABLE_PARAMS);i++)
 				{
-					found=j;
-					trans[i]=j;
-					break;
+					l=strlen(param->param[i]);
+					ADM_assert(l);
+					found=-1;
+					for(int j=0;j<nb;j++)
+					{
+						if(!strncasecmp(param->param[i],args[j].arg.string,l))
+						{
+							if(strlen(args[j].arg.string)>l && args[j].arg.string[l]=='=')
+							{
+								found=j;
+								break;
+							}
+						}
+					}
+					if(found==-1)
+					{	
+						printf("Param : %s not found or incorrect\n",param->param[i]);
+						 return NULL;
+					}
+				}
+				// if we get here, it means we found each param, time to build the couples
+				CONFcouple *couple;
+				couple=new CONFcouple(nb);
+				for(int i=0;i<nb;i++)
+				{
+					char *copy=ADM_strdup(args[i].arg.string);
+					// Search "="
+					char *where=strstr(copy,"=");
+					if(!where) ADM_assert(0);
+					*where=0;
+					if(!couple->setCouple(copy,where+1))
+						{
+							printf("Set couple failed\n");
+							delete couple;
+							return NULL;
+						}
+					ADM_dealloc(copy);
+				}
+				return couple;
+	}
+	//********************* Constant # of parameters #################
+	else
+	{
+		if(nb!=param->nb )
+		{
+			printf("# of parameters mismatch: expected %d, got %d\n",nb,param->nb);
+			return NULL;
+		}
+		// For each param check we are ok
+		// the generic form is name=value
+		// name should be the same as in the param array
+		for(int i=0;i<nb;i++)
+		{
+			l=strlen(param->param[i]);
+			ADM_assert(l);
+			found=-1;
+			for(int j=0;j<nb;j++)
+			{
+				if(!strncasecmp(param->param[i],args[j].arg.string,l))
+				{
+					if(strlen(args[j].arg.string)>l && args[j].arg.string[l]=='=')
+					{
+						found=j;
+						trans[i]=j;
+						break;
+					}
 				}
 			}
-		}
-		if(found==-1)
-		{	
-			printf("Param : %s not found or incorrect\n",param->param[i]);
-			 return NULL;
-		}
-	}
-	// if we get here, it means we found each param, time to build the couples
-	CONFcouple *couple;
-	couple=new CONFcouple(nb);
-	for(int i=0;i<nb;i++)
-	{
-		l=strlen(param->param[i]);
-		if(!couple->setCouple(param->param[i],args[ trans[i]].arg.string+l+1))
-			{
-				printf("Set couple failed\n");
-				delete couple;
-				return NULL;
+			if(found==-1)
+			{	
+				printf("Param : %s not found or incorrect\n",param->param[i]);
+				 return NULL;
 			}
+		}
+		// if we get here, it means we found each param, time to build the couples
+		CONFcouple *couple;
+		couple=new CONFcouple(nb);
+		for(int i=0;i<nb;i++)
+		{
+			l=strlen(param->param[i]);
+			if(!couple->setCouple(param->param[i],args[ trans[i]].arg.string+l+1))
+				{
+					printf("Set couple failed\n");
+					delete couple;
+					return NULL;
+				}
+		}
+		return couple;
 	}
-	return couple;
+	
 }
 uint8_t 	filterAddScript(VF_FILTERS tag,uint32_t n,Arg *args)
 {
-	// 1- searc filter
+	// 1- search filter
 	int found=-1;
 	aviInfo info;
 
 	video_body->getVideoInfo(&info);
 
-	for(unsigned int i=0;i<nb_video_filter;i++)
+	for(unsigned int i=0;i<allfilters.size();i++)
 	{
 		if(tag==allfilters[i].tag)
 		{
@@ -457,7 +466,7 @@ uint8_t 	filterAddScript(VF_FILTERS tag,uint32_t n,Arg *args)
 			return 1;
 		}
 	}
-	printf("Tag not found\n");
+	printf("Tag not found:%d\n",tag);
 	return 0;
 }
 
@@ -467,7 +476,7 @@ void filterSaveScriptJS(FILE *f)
                 {
                         VF_FILTERS tag=videofilters[i].tag;
                         qfprintf(f,"app.video.addFilter(");
-                        for(unsigned int j=0;j<nb_video_filter;j++)
+                        for(unsigned int j=0;j<allfilters.size();j++)
                                 {
                                         if(tag==allfilters[j].tag)
                                         {       
