@@ -55,12 +55,12 @@
 
 
 // MEANX
-#include "../ADM_library/default.h"
+#include "default.h"
 #include "tcrequant.h"
 
-#include "../ADM_toolkit/ADM_debugID.h"
+#include "../ADM_osSupport/ADM_debugID.h"
 #define MODULE_NAME MODULE_TCREQUANT
-#include "../ADM_toolkit/ADM_debug.h"
+#include "../ADM_osSupport/ADM_debug.h"
 #include "../ADM_assert.h"
 
 // / MEANX
@@ -85,7 +85,7 @@ static int verbose = 2;
 
 // user defined types
 //typedef unsigned int		uint;
-#ifdef CYG_MANGLING
+#ifdef ADM_WIN32
 	#define uint unsigned int
 #endif
 #ifdef ADM_BSD_FAMILY
