@@ -15,9 +15,9 @@
 #include <pthread.h>
 #define WIN32_CLASH
 #include "ADM_JSAvidemux.h"
-#include "ADM_library/default.h"
+#include "default.h"
 #include "ADM_toolkit/toolkit.hxx"
-#include "ADM_gui2/GUI_ui.h"
+#include "../ADM_userInterfaces/ADM_commonUI/GUI_ui.h"
 #include "ADM_editor/ADM_outputfmt.h"
 #include "ADM_audiofilter/audioeng_buildfilters.h"
 #include "adm_scanner.h" 
@@ -28,13 +28,13 @@
 #include "ADM_encoder/adm_encoder.h"
 #include "ADM_encoder/adm_encConfig.h"
 #include "ADM_editor/ADM_outputfmt.h"
-#include "ADM_gui2/GUI_ui.h"
+#include "../ADM_userInterfaces/ADM_commonUI/GUI_ui.h"
 #include "ADM_filter/video_filters.h"
 #include "ADM_script/ADM_container.h"
 
-#include "ADM_toolkit/ADM_debugID.h"
+#include "ADM_osSupport/ADM_debugID.h"
 #define MODULE_NAME MODULE_SCRIPT
-#include "ADM_toolkit/ADM_debug.h"
+#include "ADM_osSupport/ADM_debug.h"
 
 
 extern int A_openAvi (char *name);
@@ -46,7 +46,7 @@ extern int filterLoadXml(char *docname,uint8_t silent);
 extern int A_delete(uint32_t start, uint32_t end);
 
 extern uint8_t A_ListAllBlackFrames( char *file );
-extern uint8_t A_jumpToTime(uint32_t hh,uint32_t mm,uint32_t ss);
+extern uint8_t A_jumpToTime(uint32_t hh,uint32_t mm,uint32_t ss,uint32_t ms);
 extern uint8_t addFile(char *name);
 
 uint8_t A_setContainer(const char *cont);
@@ -484,7 +484,7 @@ JSBool ADM_JSAvidemux::GoToTime(JSContext *cx, JSObject *obj, uintN argc,
 	if(JSVAL_IS_INT(argv[0]) == false || JSVAL_IS_INT(argv[1]) == false || JSVAL_IS_INT(argv[2]) == false)
 		return JS_FALSE;
         enterLock();
-	*rval = INT_TO_JSVAL(A_jumpToTime(JSVAL_TO_INT(argv[0]),JSVAL_TO_INT(argv[1]),JSVAL_TO_INT(argv[2])));
+	*rval = INT_TO_JSVAL(A_jumpToTime(JSVAL_TO_INT(argv[0]),JSVAL_TO_INT(argv[1]),JSVAL_TO_INT(argv[2]), 0));
 	leaveLock();
 	return JS_TRUE;
 }// end GoToTime
