@@ -14,9 +14,9 @@
 #include <stdlib.h>
 #include "ADM_JSGlobal.h"
 #include "ADM_JSAvidemuxAudio.h"
-#include "ADM_library/default.h"
+#include "default.h"
 #include "ADM_toolkit/toolkit.hxx"
-#include "ADM_gui2/GUI_ui.h"
+#include "../ADM_userInterfaces/ADM_commonUI/GUI_ui.h"
 #include "ADM_audiofilter/audioeng_buildfilters.h"
 #include "avi_vars.h"
 #include "gui_action.hxx"
@@ -25,7 +25,6 @@
 #include "ADM_encoder/adm_encoder.h"
 #include "ADM_encoder/adm_encConfig.h"
 #include "ADM_editor/ADM_outputfmt.h"
-#include "ADM_gui2/GUI_ui.h"
 #include "ADM_filter/video_filters.h"
 
 
@@ -47,6 +46,7 @@ JSPropertySpec ADM_JSAvidemuxAudio::avidemuxaudio_properties[] =
         { "film2pal", film2pal_prop, JSPROP_ENUMERATE },	// convert film to pal
         { "pal2film", pal2film_prop, JSPROP_ENUMERATE },	// convert pal to film
         { "normalizeMode", normalizemode_prop, JSPROP_ENUMERATE },	//
+        { "drc", drc_prop, JSPROP_ENUMERATE },	//
         { "normalizeValue", normalizevalue_prop, JSPROP_ENUMERATE },	//
         { 0 }
 };
@@ -62,6 +62,8 @@ JSFunctionSpec ADM_JSAvidemuxAudio::avidemuxaudio_methods[] =
         { "setTrack", setTrack, 1, 0, 0 },    // set output codec
         { "secondAudioTrack", secondAudioTrack, 2, 0, 0 },    // set audio track
         { "mixer", mixer, 1, 0, 0 },    // set mixer configuration
+        { "getNbChannels", getNbChannels, 1, 0, 0 },
+        { "getBitrate", getBitrate, 1, 0, 0 },
         { 0 }
 };
 
@@ -150,7 +152,9 @@ JSBool ADM_JSAvidemuxAudio::JSGetProperty(JSContext *cx, JSObject *obj, jsval id
                         case normalizevalue_prop:
                           *vp = BOOLEAN_TO_JSVAL(priv->getObject()->m_nNormalizeValue);
                           break;
-
+                        case drc_prop:
+                            *vp = BOOLEAN_TO_JSVAL(priv->getObject()->m_bDRC);
+                            break;
 /*
                         case audio_prop:
                                 *vp = OBJECT_TO_JSVAL(priv->getObject()->m_pAudio);
@@ -179,6 +183,16 @@ JSBool ADM_JSAvidemuxAudio::JSSetProperty(JSContext *cx, JSObject *obj, jsval id
                                 leaveLock();
                                 break;
                         }
+                        case drc_prop:
+                        {
+                                if(JSVAL_IS_BOOLEAN(*vp) == false)
+                                        break;
+                                priv->getObject()->m_bDRC = JSVAL_TO_BOOLEAN(*vp);
+                                enterLock();
+                                audioFilterDrc(priv->getObject()->m_bDRC);
+                                leaveLock();
+                                break;
+                        }
                         case resample_prop:
                         {
                                 if(JSVAL_IS_INT(*vp) == false)
@@ -273,7 +287,7 @@ JSBool ADM_JSAvidemuxAudio::Save(JSContext *cx, JSObject *obj, uintN argc,
         printf("Saving Audio \"%s\"\n",pTempStr);
         enterLock();
         *rval = INT_TO_JSVAL(A_audioSave(pTempStr));
-        leaveLock()
+        leaveLock();
         return JS_TRUE;
 }// end Save
 
@@ -387,7 +401,7 @@ JSBool ADM_JSAvidemuxAudio::Codec(JSContext *cx, JSObject *obj, uintN argc,
 
                 *rval = BOOLEAN_TO_JSVAL(true);
         }// end set bitrate
-        leaveLock()
+        leaveLock();
         return JS_TRUE;
 }// end Codec
 JSBool ADM_JSAvidemuxAudio::getNbTracks(JSContext *cx, JSObject *obj, uintN argc, 
@@ -403,7 +417,7 @@ audioInfo *infos=NULL;
       
         enterLock();
         video_body->getAudioStreamsInfo(0,&nb, &infos);
-        leaveLock()
+        leaveLock();
         if(infos)
                 delete [] infos;
         *rval = INT_TO_JSVAL(nb);
@@ -428,7 +442,7 @@ audioInfo *infos=NULL;
         if(nw>nb) return JS_FALSE;
         enterLock();
         video_body->changeAudioStream(0,nw);
-        leaveLock()
+        leaveLock();
         return JS_TRUE;
 }// end Codec
 JSBool ADM_JSAvidemuxAudio::secondAudioTrack(JSContext *cx, JSObject *obj, uintN argc, jsval *argv, jsval *rval)
@@ -450,10 +464,10 @@ JSBool ADM_JSAvidemuxAudio::secondAudioTrack(JSContext *cx, JSObject *obj, uintN
         enterLock();
         if(A_setSecondAudioTrack(source,name))
         {
-                leaveLock()
+                leaveLock();
                 return JS_TRUE;
         }
-        leaveLock()
+        leaveLock();
       return JS_FALSE;
 }
 JSBool ADM_JSAvidemuxAudio::mixer(JSContext *cx, JSObject *obj, uintN argc, 
@@ -474,8 +488,56 @@ uint32_t *infos=NULL;
                 *rval=BOOLEAN_TO_JSVAL(true);
         else
                 *rval=BOOLEAN_TO_JSVAL(false);
-        leaveLock()
+        leaveLock();
         return JS_TRUE;
 
 }// end Codec
 
+JSBool ADM_JSAvidemuxAudio::getNbChannels(JSContext *cx, JSObject *obj, uintN argc, 
+                                      jsval *argv, jsval *rval)
+{
+uint32_t nb=0, nw=0;
+audioInfo *infos=NULL;
+        // default return value
+        ADM_JSAvidemuxAudio *p = (ADM_JSAvidemuxAudio *)JS_GetPrivate(cx, obj);
+        if(argc != 1)
+                return JS_FALSE;
+        // default return value
+      
+        if(JSVAL_IS_INT(argv[0]) == false)
+                return JS_FALSE;
+        enterLock();
+        video_body->getAudioStreamsInfo(0,&nb, &infos);
+        leaveLock()
+        nw=(JSVAL_TO_INT(argv[0]));
+        if(nw>nb)
+                return JS_FALSE;
+        *rval = INT_TO_JSVAL(infos[nw].channels);
+        delete [] infos;
+        return JS_TRUE;
+}// end Codec
+
+JSBool ADM_JSAvidemuxAudio::getBitrate(JSContext *cx, JSObject *obj, uintN argc, 
+                                      jsval *argv, jsval *rval)
+{
+uint32_t nb=0, nw=0;
+audioInfo *infos=NULL;
+        // default return value
+        ADM_JSAvidemuxAudio *p = (ADM_JSAvidemuxAudio *)JS_GetPrivate(cx, obj);
+        if(argc != 1)
+                return JS_FALSE;
+        // default return value
+      
+        if(JSVAL_IS_INT(argv[0]) == false)
+                return JS_FALSE;
+        enterLock();
+        video_body->getAudioStreamsInfo(0,&nb, &infos);
+        leaveLock()
+        nw=(JSVAL_TO_INT(argv[0]));
+        if(nw>nb)
+                return JS_FALSE;
+        *rval = INT_TO_JSVAL(infos[nw].bitrate);
+        delete [] infos;
+        return JS_TRUE;
+}// end Codec
+
