@@ -14,9 +14,9 @@
 #include <stdlib.h>
 #include "ADM_JSAvidemuxVideo.h"
 #include "ADM_JSGlobal.h"
-#include "ADM_library/default.h"
+#include "default.h"
 #include "ADM_toolkit/toolkit.hxx"
-#include "ADM_gui2/GUI_ui.h"
+#include "../ADM_userInterfaces/ADM_commonUI/GUI_ui.h"
 #include "ADM_audiofilter/audioeng_buildfilters.h"
 #include "avi_vars.h"
 #include "gui_action.hxx"
@@ -25,7 +25,7 @@
 #include "ADM_encoder/adm_encoder.h"
 #include "ADM_encoder/adm_encConfig.h"
 #include "ADM_editor/ADM_outputfmt.h"
-#include "ADM_gui2/GUI_ui.h"
+#include "../ADM_userInterfaces/ADM_commonUI/GUI_ui.h"
 #include "ADM_filter/video_filters.h"
 
 #include "ADM_script/ADM_container.h"
@@ -39,6 +39,7 @@ extern int A_saveJpg (char *name);
 extern uint8_t loadVideoCodecConf( char *name);
 extern int videoCodecConfigure(char *p,uint32_t i, uint8_t  *c);
 
+extern void filterCleanUp( void );
 
 
 JSPropertySpec ADM_JSAvidemuxVideo::avidemuxvideo_properties[] = 
@@ -51,6 +52,7 @@ JSFunctionSpec ADM_JSAvidemuxVideo::avidemuxvideo_methods[] =
 {
 	{ "clear", Clear, 0, 0, 0 },	// clear
 	{ "add", Add, 3, 0, 0 },	// add
+        { "clearFilters", ClearFilters, 0, 0, 0 }, // Delete all filters
 	{ "addFilter", AddFilter, 10, 0, 0 },	// Add filter to filter chain
 	{ "codec", Codec, 3, 0, 0 },	// Set the video codec
 	{ "codecConf", CodecConf, 1, 0, 0 },	// load video codec config
@@ -60,12 +62,15 @@ JSFunctionSpec ADM_JSAvidemuxVideo::avidemuxvideo_methods[] =
 	{ "setPostProc", PostProcess, 3, 0, 0 },	// Postprocess
         { "setFps1000", SetFps1000, 1, 0, 0 },        // Postprocess
         { "getFps1000", GetFps1000, 0, 0, 0 },        // Postprocess
+        { "getNbFrames", GetNbFrames, 0, 0, 0 },        // Postprocess
         { "getWidth", GetWidth, 0, 0, 0 },        // Postprocess
         { "getHeight", GetHeight, 0, 0, 0 },        // Postprocess
         { "getFCC", GetFCC, 0, 0, 0 },        // Postprocess
         { "isVopPacked", isVopPacked, 0, 0, 0 },        // Postprocess
         { "hasQpel", hasQpel, 0, 0, 0 },        // Postprocess
         { "hasGmc", hasGmc, 0, 0, 0 },        // Postprocess
+        { "frameSize", getFrameSize, 1, 0, 0 },        // FrameSize
+        { "frameType", getFrameType, 1, 0, 0 },        // Postprocess
 	{ 0 }
 };
 
@@ -192,6 +197,13 @@ JSBool ADM_JSAvidemuxVideo::Add(JSContext *cx, JSObject *obj, uintN argc,
 }// end Add
 
 
+JSBool ADM_JSAvidemuxVideo::ClearFilters(JSContext *cx, JSObject *obj, uintN argc,
+                                       jsval *argv, jsval *rval)
+{// begin Clear
+	filterCleanUp();
+        return JS_TRUE;
+}// end Clear
+
 
 JSBool ADM_JSAvidemuxVideo::AddFilter(JSContext *cx, JSObject *obj, uintN argc, 
                                        jsval *argv, jsval *rval)
@@ -240,8 +252,10 @@ JSBool ADM_JSAvidemuxVideo::Codec(JSContext *cx, JSObject *obj, uintN argc,
         if(JSVAL_IS_STRING(argv[0]) == false || JSVAL_IS_STRING(argv[1]) == false  || JSVAL_IS_STRING(argv[2]) == false)
                 return JS_FALSE;
         
-
-                printf("Valid codec conf %s found.\n",JS_GetStringBytes(JSVAL_TO_STRING(argv[2])));
+                printf("[codec]%s\n",JS_GetStringBytes(JSVAL_TO_STRING(argv[0])));
+                printf("[conf ]%s\n",JS_GetStringBytes(JSVAL_TO_STRING(argv[1])));
+                printf("[xtra ]%s\n",JS_GetStringBytes(JSVAL_TO_STRING(argv[2])));
+                
                 char *codec,*conf,*codecConfString;
                 codec = JS_GetStringBytes(JSVAL_TO_STRING(argv[0]));
                 conf = JS_GetStringBytes(JSVAL_TO_STRING(argv[1]));
@@ -373,6 +387,20 @@ aviInfo info;
         *rval = INT_TO_JSVAL(info.fps1000);
         return JS_TRUE;
 }// end PostProcess
+JSBool ADM_JSAvidemuxVideo::GetNbFrames(JSContext *cx, JSObject *obj, uintN argc, 
+                                       jsval *argv, jsval *rval)
+{// begin PostProcess
+aviInfo info;
+        if(argc != 0)
+          return JS_FALSE;
+        
+        enterLock();
+        video_body->getVideoInfo(&info);
+        leaveLock();
+        
+        *rval = INT_TO_JSVAL(info.nb_frames);
+        return JS_TRUE;
+}// end PostProcess
 
 JSBool ADM_JSAvidemuxVideo::SetFps1000(JSContext *cx, JSObject *obj, uintN argc, 
                                        jsval *argv, jsval *rval)
@@ -499,3 +527,40 @@ uint32_t info;
         if(info & ADM_QPEL_ON) *rval=JS_TRUE;
         return JS_TRUE;
 }// end PostProcess
+
+
+JSBool ADM_JSAvidemuxVideo::getFrameSize(JSContext *cx, JSObject *obj, uintN argc, 
+                                       jsval *argv, jsval *rval)
+{// begin PostProcess
+uint32_t info;
+uint32_t frame;
+uint32_t sz;
+        if(argc != 1)
+          return JS_FALSE;
+        
+        enterLock();
+        frame=JSVAL_TO_INT(argv[0]);
+        if(!video_body->getFrameSize(frame,&sz)) return JS_FALSE;
+        leaveLock(); 
+        
+        *rval=INT_TO_JSVAL(sz);
+        return JS_TRUE;
+}// end PostProcess
+JSBool ADM_JSAvidemuxVideo::getFrameType(JSContext *cx, JSObject *obj, uintN argc, 
+                                       jsval *argv, jsval *rval)
+{// begin PostProcess
+uint32_t info;
+uint32_t frame;
+uint32_t sz;
+        if(argc != 1)
+          return JS_FALSE;
+        
+        enterLock();
+        frame=JSVAL_TO_INT(argv[0]);
+        if(!video_body->getFlags(frame,&sz)) return JS_FALSE;
+        leaveLock(); 
+        
+        *rval=INT_TO_JSVAL(sz);
+        return JS_TRUE;
+}// end PostProcess
+/* EOF */
