@@ -21,13 +21,16 @@ void GUI_FileSelWrite(const char *label,SELFILE_CB cb) ;
 void GUI_FileSelRead(const char *label, char * * name);
 void GUI_FileSelWrite(const char *label, char * * name);
 
+uint8_t FileSel_SelectWrite(const char *title,char *target,uint32_t max, const char *source);
 uint8_t FileSel_SelectRead(const char *title,char *target,uint32_t max, const char *source);
+uint8_t FileSel_SelectDir(const char *title,char *target,uint32_t max, const char *source);
 
 char *ADM_getBaseDir(void);
 char *ADM_getJobDir(void);
 char *ADM_getCustomDir(void);
 
-uint8_t buildDirectoryContent(uint32_t *outnb,const char *base, char *jobName[],int maxElems);
+uint8_t buildDirectoryContent(uint32_t *outnb,const char *base, char *jobName[],int maxElems,const char *ext);
 const char *GetFileName(const char *str);
+uint8_t ADM_mkdir(const char *name);
 #endif
 //EOF
