@@ -14,20 +14,12 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#include "config.h"
- 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-
-#include <time.h>
-#include <sys/time.h>
-
 
+#include "default.h"
 
 #include "fourcc.h"
 #include "avio.hxx"
-#include <ADM_assert.h>
+#include "ADM_assert.h"
 
 #include "ADM_video/ADM_confCouple.h"
 static char tmpstring[1024]; // should be enougth
@@ -50,8 +42,8 @@ CONFcouple::~CONFcouple()
 {
 	for(uint32_t i=0;i<nb;i++)
 		{
-			if(name[i]) delete [] name[i];
-			if(value[i]) delete [] value[i];
+			if(name[i]) delete name[i];
+			if(value[i]) delete value[i];
 		}
 		delete [] name;
 		delete [] value;
@@ -118,7 +110,6 @@ uint8_t CONFcouple::setCouple(const char *myname,const ADM_filename *val)
 	return 1;
 }
 
-
 uint8_t CONFcouple::getCouple(const char *myname,uint32_t *val)
 {
 	int32_t index=lookupName(myname);
@@ -155,9 +146,10 @@ uint8_t CONFcouple::getCouple(const char *myname,ADM_filename **val)
 	*val=(ADM_filename *)ADM_strdup(value[index]);
 	return 1;
 }
+
 uint8_t CONFcouple::getCouple(const char *myname,float *val)
 {
-int32_t index=lookupName(myname);
+	int32_t index=lookupName(myname);
 
 	ADM_assert(index!=-1);
 	ADM_assert(index<(int)nb);
