@@ -43,7 +43,7 @@ Skip factor=2
 #include "ADM_editor/ADM_edit.hxx"
 #include "ADM_video/ADM_genvideo.hxx"
 #include "ADM_video/ADM_vidCommonFilter.h"
-#include "ADM_toolkit/ADM_cpuCap.h"
+#include "ADM_osSupport/ADM_cpuCap.h"
 //#define MMX_TRACE
 #define ASM_ILACING
 
@@ -145,6 +145,7 @@ pxor_r2r(mm7,mm7);
 	for(y=h>>SKIP_FACTOR;  y >2 ; y--)
 		{
 			__asm__ __volatile__(
+                                "push "REG_bx"\n\t"
 				"mov "Mangle(_l_c)",	"REG_ax"\n\t"
 				"mov "Mangle(_l_p)",	"REG_bx"\n\t"
 				"mov "Mangle(_l_n)",	"REG_cx"\n\t"
@@ -155,7 +156,7 @@ pxor_r2r(mm7,mm7);
 				"movd ("REG_cx"),	%%mm2\n\t"
 				:
 				:
-				: "eax", "ebx", "ecx", "edx"
+				: "eax",  "ecx", "edx"
 				);
 				COMPUTE
 
@@ -165,9 +166,10 @@ pxor_r2r(mm7,mm7);
 				"add $4,		"REG_cx"\n\t"
 				"sub $1,		"REG_dx"\n\t"
 				"jnz 		8b\n\t"
+                                "pop "REG_bx"\n\t"
 				:
 				:
-				: "eax", "ebx", "ecx", "edx"
+				: "eax", "ecx", "edx"
 				);
 
 
