@@ -28,6 +28,7 @@
 #include "config.h"
 #include "ADM_editor/ADM_edit.hxx"
 #include "ADM_video/ADM_genvideo.hxx"
+#include "ADM_video/ADM_videoNull.h"
 
 
 
@@ -68,6 +69,7 @@ uint8_t AVDMVideoStreamRaw::getFrameNumberNoAlloc(uint32_t frame,
 {
         UNUSED_ARG(len);
     	UNUSED_ARG(flags);
+                if(frame>= _info.nb_frames) return 0;
 		*len=(_info.width*_info.height*3)>>1;
 		if(!(frame<_info.nb_frames))
 		{
