@@ -32,14 +32,14 @@ uint32_t nb;
 char     *name;
         memset(jobName,0,sizeof(jobName));
 
-        if(!buildDirectoryContent(&nb,ADM_getJobDir(),jobName,MAX_JOBS))
+        if(!buildDirectoryContent(&nb,ADM_getJobDir(),jobName,MAX_JOBS,".js"))
         {
-          GUI_Error_HIG(_("Oops"),_("Something very wrong happened when buildint joblist"));
+          GUI_Error_HIG(QT_TR_NOOP("Oops"),QT_TR_NOOP("Something very wrong happened when building joblist."));
                 return 0;
         }
         if(!nb)
         {
-          GUI_Info_HIG(ADM_LOG_IMPORTANT,_("Nothing to do."),_("There is no jobs stored, nothing to do"));
+          GUI_Info_HIG(ADM_LOG_IMPORTANT,QT_TR_NOOP("There are no jobs stored"), NULL);
                 return 1;
         }
         DIA_job(nb,jobName);
