@@ -26,7 +26,7 @@
 
 
 #include "avi_vars.h"
-#include "ADM_gui2/GUI_ui.h"
+#include "GUI_ui.h"
 #include "ADM_toolkit/toolkit.hxx"
 #include "ADM_assert.h"
 
@@ -45,10 +45,11 @@ extern void setVideoEncoderSettings (COMPRESSION_MODE mode, uint32_t param,
 
 uint8_t A_autoDrive(Action action)
 {
+  uint32_t fq;
         //
         if(!currentaudiostream)
         {
-          GUI_Error_HIG(_("No audio track"),_( "An audio track is necessary to create such file"));
+          GUI_Error_HIG(QT_TR_NOOP("No audio track"),QT_TR_NOOP( "An audio track is necessary to create such file"));
                 return 0;
         }
 
@@ -56,23 +57,132 @@ uint8_t A_autoDrive(Action action)
 #define PSP_AUDIO_FQ 24000        
         switch(action)
         {
-                case ACT_AUTO_PSP:
-                                // Resize
-                                if(!setPSP()) return 0;
-                                // Video codec
-#ifdef USE_X264
-                    if(!videoCodecSelectByName("X264")) 
+                case ACT_AUTO_IPOD:
+#if  !defined(USE_XVID_4) || (!defined(USE_FAAC) && !defined(HAVE_MP3LAME))
+                  GUI_Error_HIG(QT_TR_NOOP("Codec Error"),
+                                        QT_TR_NOOP( "You need Xvid4 and either LAME or FAAC support for the iPod profile"));
 #else
-                    if(!videoCodecSelectByName("FFMpeg4"))            
-#endif
+                    if(!setIPOD())
                     {
-                      GUI_Error_HIG(_("Codec Error"),_( "Cannot select mpeg4 sp codec."));
                         return 0;
                     }
+                
+                    // Video codec
+
+                    if(!videoCodecSelectByName("XVID4")) 
+                    {
+                      GUI_Error_HIG(QT_TR_NOOP("Codec Error"),QT_TR_NOOP( "Cannot select the MPEG-4 SP codec."));
+                        return 0;
+                    }
+                    setIpod_Xvid4Preset();
                     // Set mode & bitrate 
-                    setVideoEncoderSettings(COMPRESS_CBR,768,0,NULL);
+                    setVideoEncoderSettings(COMPRESS_CBR,400,0,NULL);
                     // Audio Codec
-                    if((currentaudiostream->getInfo()->frequency==PSP_AUDIO_FQ)&&
+                    if(   (currentaudiostream->getInfo()->channels==2)&&
+                        (currentaudiostream->getInfo()->encoding==WAV_AAC ||
+                         currentaudiostream->getInfo()->encoding==WAV_MP3))
+                    {
+                        audioCodecSetcodec(AUDIOENC_COPY);
+                    }
+                    else
+                    {
+#if defined(USE_FAAC)
+                          audioCodecSetcodec(AUDIOENC_FAAC);
+#elif defined(HAVE_MP3LAME)
+                          audioCodecSetcodec(AUDIOENC_MP3);
+#endif
+                          audioFilter_SetBitrate(128);
+                      }
+#endif
+                      break;
+//******************************** IPOD *******************************
+                          
+                          
+                          break;
+        		case ACT_AUTO_FLV:
+        			// Check audio is mp3 @ 44.1/22.05/11.025 kHz MP3
+        			if(currentaudiostream)
+        			{
+        				fq=currentaudiostream->getInfo()->frequency;
+        				if(currentaudiostream->getInfo()->encoding==WAV_MP3 && (fq==44100 || fq==22050 || fq==11025))
+        						{
+        	                		audioCodecSetcodec(AUDIOENC_COPY);
+        						}
+        				else
+        				{
+#ifdef HAVE_LIBMP3LAME
+        					audioCodecSetcodec(AUDIOENC_MP3);
+        					audioFilter_SetBitrate(128);
+                                                audioFilter_MP3DisableReservoir(1);
+        					// set fq
+        					
+#else
+        					 GUI_Error_HIG(QT_TR_NOOP("Codec Error"),
+        					        QT_TR_NOOP( "You don't have LAME!.\nIt is needed to create FLV  video."));
+#endif
+        					 if(fq==44100 || fq==22050 || fq==11025)
+        					         						{}
+        					 else
+        					 {
+        						 audioFilterResample(22050);
+        					 }
+        					 
+        				}
+        			}
+        			// Now video
+        			 if(!videoCodecSelectByName("FLV1")) 
+                    {
+                      GUI_Error_HIG(QT_TR_NOOP("Codec Error"),QT_TR_NOOP( "Cannot select FLV1  codec."));
+                        return 0;
+                    }
+        			break;
+        			
+                case ACT_AUTO_PSP:
+                case ACT_AUTO_PSP_H264:
+                    // Resize
+                  if(action==ACT_AUTO_PSP_H264)
+                  {
+                    if(!setPSPFullRes()) return 0;
+                  }
+                  else
+                  {
+                    if(!setPSP()) return 0;
+                  }
+                    // Video codec
+                    switch(action)
+                    {
+                    case ACT_AUTO_PSP:
+                          {
+#ifdef USE_XVID_4
+                            if(!videoCodecSelectByName("XVID4")) 
+#else
+                            if(!videoCodecSelectByName("FFMpeg4"))            
+#endif
+                            {
+                              GUI_Error_HIG(QT_TR_NOOP("Codec Error"),QT_TR_NOOP( "Cannot select mpeg4 sp codec."));
+                                return 0;
+                            }
+                            // Set mode & bitrate 
+                            setVideoEncoderSettings(COMPRESS_CBR,768,0,NULL);
+                            fq=24000;
+                          }
+                          break;
+                    case ACT_AUTO_PSP_H264:
+                    {
+#ifdef USE_X264
+                          videoCodecSelectByName("X264"); 
+                          setPSP_X264Preset(); 
+                          setVideoEncoderSettings(COMPRESS_CBR,768,0,NULL);
+#endif
+                          fq=48000;
+                    }
+                    break;
+                    
+                    default:
+                          ADM_assert(0);
+                    }
+                    // Audio Codec
+                    if((currentaudiostream->getInfo()->frequency==fq)&&
                         (currentaudiostream->getInfo()->channels==2)&&
                         (currentaudiostream->getInfo()->encoding==WAV_AAC))
                     {
@@ -83,14 +193,15 @@ uint8_t A_autoDrive(Action action)
 #ifdef USE_FAAC
                           audioCodecSetcodec(AUDIOENC_FAAC);
 #else
-                          GUI_Error_HIG(_("Codec Error"),_( "You don't have FAAC!.\nIt is needed to create PSP compatible video."));
+                          GUI_Error_HIG(QT_TR_NOOP("Codec Error"),
+                                        QT_TR_NOOP( "You don't have FAAC!.\nIt is needed to create PSP compatible video."));
 #endif
                                     // ? Needed ?
-                          if(currentaudiostream->getInfo()->frequency!=PSP_AUDIO_FQ)
+                          if(currentaudiostream->getInfo()->frequency!=fq)
                           {
-                              audioFilterResample(PSP_AUDIO_FQ);
+                              audioFilterResample(fq);
                           }
-                          audioFilter_SetBitrate(64);
+                          audioFilter_SetBitrate(128);
                       }
                                 break;
                 case ACT_AUTO_VCD:
@@ -188,11 +299,21 @@ uint8_t A_autoDrive(Action action)
         }
         // Set output format to mpeg PS
         // Except for PSP
-        if(action==ACT_AUTO_PSP)
-          UI_SetCurrentFormat(ADM_PSP);
-        else
-          UI_SetCurrentFormat(ADM_PS);
-        
+        switch(action)
+        {
+          case ACT_AUTO_IPOD:
+              UI_SetCurrentFormat(ADM_MP4);
+              break;
+          case ACT_AUTO_PSP:
+          case ACT_AUTO_PSP_H264:
+              UI_SetCurrentFormat(ADM_PSP);
+              break;
+          case ACT_AUTO_FLV:
+        	  UI_SetCurrentFormat(ADM_FLV);
+        	  break;
+          default:
+              UI_SetCurrentFormat(ADM_PS);
+        }
         return 1;
 }
 //EOF
